/***************************************************************************
*
*	File name : clg_drv.c
*	Function  : CLG Driver
*	Revision  :
*		08/31/2007	Nariai		First revision
*
****************************************************************************/

// Include Files
#include	"reg_801.h"
#include	"clg_drv.h"
#include	"clg_api.h"

// Prototype
void ClgInit(unsigned char usage, T_CLG_CFG *pConfig);\
void ClgStart(unsigned char usage);
void ClgStop(unsigned char usage);
void ClgIntHdlr(unsigned char usage);

static void ClgUart0Init(T_CLG_CFG *pConfig);
static void ClgSpiInit(T_CLG_CFG *pConfig);
static void ClgI2cInit(T_CLG_CFG *pConfig);
static void ClgUart0Start(void);
static void ClgSpiStart(void);
static void ClgI2cStart(void);
static void ClgUart0Stop(void);
static void ClgSpiStop(void);
static void ClgI2cStop(void);
static void ClgUart0IntHdlr(void);
static void ClgSpiIntHdlr(void);
static void ClgI2cIntHdlr(void);


// Global
unsigned short	g_ClgUartCnt;
unsigned short	g_ClgSpiCnt;
unsigned short	g_ClgI2cCnt;


/***************************************************************************
	ClgInit

	description	: Init. CLG
	argument	: usage		: usage of CLG
				: pConfig	: pointer of CLG configuration info.
	return: 	: None
***************************************************************************/
void ClgInit(unsigned char usage, T_CLG_CFG *pConfig){
	
	switch(usage){
		case CLG_FOR_UART0:
			ClgUart0Init(pConfig);
			break;
			
		case CLG_FOR_SPI:
			ClgSpiInit(pConfig);
			break;
			
		case CLG_FOR_I2C:
			ClgI2cInit(pConfig);
			break;
			
		default:
			break;
			
	}
	
	return;
	
}


/***************************************************************************
	ClgStart

	description	: Start CLG
	argument	: usage		: usage of CLG
	return: 	: None
***************************************************************************/
void ClgStart(unsigned char usage){
	
	switch(usage){
		case CLG_FOR_UART0:
			ClgUart0Start();
			break;
			
		case CLG_FOR_SPI:
			ClgSpiStart();
			break;
			
		case CLG_FOR_I2C:
			ClgI2cStart();
			break;
			
		default:
			break;
			
	}
	
	return;
	
}


/***************************************************************************
	ClgStop

	description	: Stop CLG
	argument	: usage		: usage of CLG
	return: 	: None
***************************************************************************/
void ClgStop(unsigned char usage){
	
	switch(usage){
		case CLG_FOR_UART0:
			ClgUart0Stop();
			break;
			
		case CLG_FOR_SPI:
			ClgSpiStop();
			break;
			
		case CLG_FOR_I2C:
			ClgI2cStop();
			break;
			
		default:
			break;
			
	}
	
	return;
	
}


/***************************************************************************
	ClgIntHdlr

	description	: CLG interrupt handler
	argument	: usage		: usage of CLG
	return: 	: None
***************************************************************************/
void ClgIntHdlr(unsigned char usage){
	
	switch(usage){
		case CLG_FOR_UART0:
			ClgUart0IntHdlr();
			break;
			
		case CLG_FOR_SPI:
			ClgSpiIntHdlr();
			break;
			
		case CLG_FOR_I2C:
			ClgI2cIntHdlr();
			break;
			
		default:
			break;
			
	}
	
	return;
	
}


/* ----- static ----- */


/***************************************************************************
	ClgUart0Init

	description	: Init. CLG UART 0
	argument	: pConfig	: pointer of CLG configuration info.
	return: 	: None
***************************************************************************/
static void ClgUart0Init(T_CLG_CFG *pConfig){
	
	// Set count mode
	if(pConfig->countMode == CLG_COUNT_REPEAT){
		// Repeat
		ClgUart0_SetRepeat();
		
	} else {
		// One shot
		ClgUart0_SetOneShot();
		
	}
	
	// Select input clock
	ClgUart0_SetInputClkSel(pConfig->inputClockSel);
	
	// Set reload data
	ClgUart0_SetReloadData(pConfig->reloadData);
	
	return;
	
}


/***************************************************************************
	ClgSpiInit

	description	: Init. CLG SPI
	argument	: pConfig	: pointer of CLG configuration info.
	return: 	: None
***************************************************************************/
static void ClgSpiInit(T_CLG_CFG *pConfig){

	// Set count mode
	if(pConfig->countMode == CLG_COUNT_REPEAT){
		// Repeat
		ClgSpi_SetRepeat();
		
	} else {
		// One shot
		ClgSpi_SetOneShot();
		
	}
	
	// Select input clock
	ClgSpi_SetInputClkSel(pConfig->inputClockSel);
	
	// Set reload data
	ClgSpi_SetReloadData(pConfig->reloadData);
	
	return;
	
}


/***************************************************************************
	ClgI2cInit

	description	: Init. CLG I2C
	argument	: pConfig	: pointer of CLG configuration info.
	return: 	: None
***************************************************************************/
static void ClgI2cInit(T_CLG_CFG *pConfig){

	// Set count mode
	if(pConfig->countMode == CLG_COUNT_REPEAT){
		// Repeat
		ClgI2c_SetRepeat();
		
	} else {
		// One shot
		ClgI2c_SetOneShot();
		
	}
	
	// Select input clock
	ClgI2c_SetInputClkSel(pConfig->inputClockSel);
	
	// Set reload data
	ClgI2c_SetReloadData(pConfig->reloadData);
	
	return;
	
}


/***************************************************************************
	ClgUart0Start

	description	: Start CLG UART 0
	argument	: None
	return: 	: None
***************************************************************************/
static void ClgUart0Start(void){
	
	// Reset timer
	ClgUart0_TimerReset();
	
	// Start timer
	ClgUart0_TimerRun();
	
	return;
	
}


/***************************************************************************
	ClgSpiStart

	description	: Start CLG SPI
	argument	: None
	return: 	: None
***************************************************************************/
static void ClgSpiStart(void){

	// Reset timer
	ClgSpi_TimerReset();
	
	// Start timer
	ClgSpi_TimerRun();
	
	return;
	
}


/***************************************************************************
	ClgI2cStart

	description	: Start CLG I2C
	argument	: None
	return: 	: None
***************************************************************************/
static void ClgI2cStart(void){

	// Reset timer
	ClgI2c_TimerReset();
	
	// Start timer
	ClgI2c_TimerRun();
	
	return;
	
}


/***************************************************************************
	ClgUart0Stop

	description	: Stop CLG UART 0
	argument	: None
	return: 	: None
***************************************************************************/
static void ClgUart0Stop(void){
	
	// Stop timer
	ClgUart0_TimerStop();
	
	return;
	
}


/***************************************************************************
	ClgSpiStop

	description	: Stop CLG SPI
	argument	: None
	return: 	: None
***************************************************************************/
static void ClgSpiStop(void){
	
	// Stop timer
	ClgSpi_TimerStop();
	
	return;
	
}


/***************************************************************************
	ClgI2cStop

	description	: Stop CLG I2C
	argument	: None
	return: 	: None
***************************************************************************/
static void ClgI2cStop(void){
	
	// Stop timer
	ClgI2c_TimerStop();
	
	return;
	
}


/***************************************************************************
	ClgUart0IntHdlr

	description	: CLG UART 0 interrupt handler
	argument	: None
	return: 	: None
***************************************************************************/
static void ClgUart0IntHdlr(void){
	
	g_ClgUartCnt++;
	
	return;
	
}


/***************************************************************************
	ClgSpiIntHdlr

	description	: CLG SPI interrupt handler
	argument	: None
	return: 	: None
***************************************************************************/
static void ClgSpiIntHdlr(void){
	
	g_ClgSpiCnt++;
	
	return;
	
}


/***************************************************************************
	ClgI2cIntHdlr

	description	: CLG I2C interrupt handler
	argument	: None
	return: 	: None
***************************************************************************/
static void ClgI2cIntHdlr(void){
	
	g_ClgI2cCnt++;
	
	return;
	
}
