/***************************************************************************
*
*	File name : reg_801.h
*	Function  : C17801 register header (C17801)
*	Revision  :
*		August. 20, 2007	Yakushiji		First revision
*
****************************************************************************/

#ifndef	___REG_801_H___
#define	___REG_801_H___

/*****************************************************************************
    PSC     (0x00004020)    Prescaler Controller
*****************************************************************************/

// 0x00004020   Prescaler control register
#define PSC_CTL                         (*(volatile unsigned char*)0x00004020)
    // [0]      Prescaler run/stop control
    #define PSC_CTL_PRUN                    0x01

    // [1]      Prescaler run/stop in debug mode
    #define PSC_CTL_PRUND                   0x02


// 0x0000403f   Prescaler configuration ID register
#define PSC_ID                          (*(volatile unsigned char*)0x0000403f)
    // [7:0]    Configuration ID
    #define PSC_ID_PSID                     0xff


/*****************************************************************************
    UART    (0x00004100)    UART Control
*****************************************************************************/

// 0x00004100   UART Status register
#define UART_ST                         (*(volatile unsigned char*)0x00004100)
    // [0]      Transmit data buffer empty flag
    #define UART_ST_TDBE                    0x01

    // [1]      Receive data ready flag
    #define UART_ST_RDRY                    0x02

    // [2]      Transmit busy flag
    #define UART_ST_TRBS                    0x04

    // [3]      Second byte receive flag
    #define UART_ST_RD2B                    0x08

    // [4]      Overrun error flag
    #define UART_ST_OER                     0x10

    // [5]      Parity error flag
    #define UART_ST_PER                     0x20

    // [6]      Framing error flag
    #define UART_ST_FER                     0x40


// 0x00004101   UART Transmit data register
#define UART_TXD                        (*(volatile unsigned char*)0x00004101)
    // [7:0]    Transmit data
    #define UART_TXD_TXD                    0xff


// 0x00004102   UART Receive data register
#define UART_RXD                        (*(volatile unsigned char*)0x00004102)
    // [7:0]    Receive data in the receive data buffer
    #define UART_RXD_RXD                    0xff


// 0x00004103   UART Mode register
#define UART_MOD                        (*(volatile unsigned char*)0x00004103)
    // [0]      Input clock select
    #define UART_MOD_SSCK                   0x01

    // [1]      Stop bit select
    #define UART_MOD_STPB                   0x02

    // [2]      Parity mode select
    #define UART_MOD_PMD                    0x04

    // [3]      Parity enable
    #define UART_MOD_PREN                   0x08

    // [4]      Character length
    #define UART_MOD_CHLN                   0x10


// 0x00004104   UART Control register
#define UART_CTL                        (*(volatile unsigned char*)0x00004104)
    // [0]      UART enable
    #define UART_CTL_RXEN                   0x01

    // [1]      Receive buffer full int. condition
    #define UART_CTL_RBFI                   0x02

    // [4]      Transmit buffer empty int. enable
    #define UART_CTL_TIEN                   0x10

    // [5]      Receive buffer full int. enable
    #define UART_CTL_RIEN                   0x20

    // [6]      Receive error int. enable
    #define UART_CTL_REIEN                  0x40


// 0x00004105   UART Expansion register
#define UART_EXP                        (*(volatile unsigned char*)0x00004105)
    // [0]      IrDA mode select
    #define UART_EXP_IRMD                   0x01

    // [6:4]    IrDA receive detection clock select
    #define UART_EXP_IRCLK                  0x70


/*****************************************************************************
    CLG     (0x00004200)    Clock Generator
*****************************************************************************/

// 0x00004200   16Bit Ch0 Input clock select register
#define CLG_T16U0_CLK                   (*(volatile unsigned short*)0x00004200)
    // [3:0]    Timer input clock select
    #define CLG_T16U0_CLK_DF                0x000f


// 0x00004202   16bit Ch0 reload data register
#define CLG_T16U0_TR                    (*(volatile unsigned short*)0x00004202)
    // [15:0]   16bit timer reload data
    #define CLG_T16U0_TR_TR                 0xffff


// 0x00004204   16bit Ch0 counter data register
#define CLG_T16U0_TC                    (*(volatile unsigned short*)0x00004204)
    // [15:0]   16bit timer counter data
    #define CLG_T16U0_TC_TC                 0xffff


// 0x00004206   16bit Ch0 control register
#define CLG_T16U0_CTL                   (*(volatile unsigned short*)0x00004206)
    // [0]      16bit timer ch0 run/stop control
    #define CLG_T16U0_CTL_PRUN              0x0001

    // [1]      16bit timer ch0 reset
    #define CLG_T16U0_CTL_PRESER            0x0002

    // [4]      16bit timer ch0 count mode select
    #define CLG_T16U0_CTL_TRMD              0x0010


// 0x00004240   T8S Input Clock Select Register
#define CLG_T8S_CLK                     (*(volatile unsigned short*)0x00004240)
    // [3:0]    Timer input clock select
    #define CLG_T8S_CLK_DF                  0x000f


// 0x00004242   T8S reload data register
#define CLG_T8S_TR                      (*(volatile unsigned short*)0x00004242)
    // [7:0]    8bit timer reload data
    #define CLG_T8S_TR_TR                   0x00ff


// 0x00004244   T8S counter data register
#define CLG_T8S_TC                      (*(volatile unsigned short*)0x00004244)
    // [7:0]    8bit timer counter data
    #define CLG_T8S_TC_TC                   0x00ff


// 0x00004246   T8S control register
#define CLG_T8S_CTL                     (*(volatile unsigned short*)0x00004246)
    // [0]      8bit timer run/stop control
    #define CLG_T8S_CTL_PRUN                0x0001

    // [1]      8bit timer reset
    #define CLG_T8S_CTL_PRESER              0x0002

    // [4]      8bit timer count mode select
    #define CLG_T8S_CTL_TRMD                0x0010


// 0x00004260   T8I Input Clock Select Register
#define CLG_T8I_CLK                     (*(volatile unsigned short*)0x00004260)
    // [3:0]    Timer input clock select
    #define CLG_T8I_CLK_DF                  0x000f


// 0x00004262   T8I reload data register
#define CLG_T8I_TR                      (*(volatile unsigned short*)0x00004262)
    // [7:0]    8bit timer reload data
    #define CLG_T8I_TR_TR                   0x00ff


// 0x00004264   T8I counter data register
#define CLG_T8I_TC                      (*(volatile unsigned short*)0x00004264)
    // [7:0]    8bit timer counter data
    #define CLG_T8I_TC_TC                   0x00ff


// 0x00004266   T8I control register
#define CLG_T8I_CTL                     (*(volatile unsigned short*)0x00004266)
    // [0]      8bit timer run/stop control
    #define CLG_T8I_CTL_PRUN                0x0001

    // [1]      8bit timer reset
    #define CLG_T8I_CTL_PRESER              0x0002

    // [4]      8bit timer count mode select
    #define CLG_T8I_CTL_TRMD                0x0010


/*****************************************************************************
    ITC     (0x000042e0)    Interrupt Controller
*****************************************************************************/

// 0x000042e0   Interrupt factor register
#define ITC_AITFT                       (*(volatile unsigned short*)0x000042e0)
    // [0]      16bit timer Ch0 factor
    #define ITC_AITFT_AIFT0                 0x0001

    // [1]      16bit timer Ch1 factor
    #define ITC_AITFT_AIFT1                 0x0002

    // [2]      ADC range factor
    #define ITC_AITFT_AIFT2                 0x0004

    // [3]      ADC end factor
    #define ITC_AITFT_AIFT3                 0x0008

    // [4]      RTC factor
    #define ITC_AITFT_AIFT4                 0x0010

    // [5]      8bit timer Ch0 factor
    #define ITC_AITFT_AIFT5                 0x0020

    // [6]      8bit timer Ch1 factor
    #define ITC_AITFT_AIFT6                 0x0040

    // [7]      8bit timer Ch2 factor
    #define ITC_AITFT_AIFT7                 0x0080

    // [8]      8bit timer Ch3 factor
    #define ITC_AITFT_AIFT8                 0x0100

    // [9]      LCDC factor
    #define ITC_AITFT_AIFT9                 0x0200

    // [10]     SPI Ch1 factor
    #define ITC_AITFT_AIFT10                0x0400

    // [11]     USB factor
    #define ITC_AITFT_AIFT11                0x0800

    // [12]     I2S transmit factor
    #define ITC_AITFT_AIFT12                0x1000

    // [13]     I2S receive factor
    #define ITC_AITFT_AIFT13                0x2000

    // [14]     REMC factor
    #define ITC_AITFT_AIFT14                0x4000


// 0x000042e2   Interrupt enable register
#define ITC_AITEN                       (*(volatile unsigned short*)0x000042e2)
    // [0]      16bit timer Ch0 enable
    #define ITC_AITEN_AIEN0                 0x0001

    // [1]      16bit timer Ch1 enable
    #define ITC_AITEN_AIEN1                 0x0002

    // [2]      ADC range enable
    #define ITC_AITEN_AIEN2                 0x0004

    // [3]      ADC endenable
    #define ITC_AITEN_AIEN3                 0x0008

    // [4]      RTC enable
    #define ITC_AITEN_AIEN4                 0x0010

    // [5]      8bit timer Ch0 enable
    #define ITC_AITEN_AIEN5                 0x0020

    // [6]      8bit timer Ch1 enable
    #define ITC_AITEN_AIEN6                 0x0040

    // [7]      8bit timer Ch2 enable
    #define ITC_AITEN_AIEN7                 0x0080

    // [8]      8bit timer Ch3 enable
    #define ITC_AITEN_AIEN8                 0x0100

    // [9]      LCDC enable
    #define ITC_AITEN_AIEN9                 0x0200

    // [10]     SPI Ch1 enable
    #define ITC_AITEN_AIEN10                0x0400

    // [11]     USB enable
    #define ITC_AITEN_AIEN11                0x0800

    // [12]     I2S transmit enable
    #define ITC_AITEN_AIEN12                0x1000

    // [13]     I2S receive enable
    #define ITC_AITEN_AIEN13                0x2000

    // [14]     REMC enable
    #define ITC_AITEN_AIEN14                0x4000


// 0x000042e6   Additional interrupt level register 0
#define ITC_ATILV0                      (*(volatile unsigned short*)0x000042e6)
    // [2:0]    16bit timer Ch0 int level
    #define ITC_ATILV0_AILV0                0x0007

    // [10:8]   16bit timer Ch1 int level
    #define ITC_ATILV0_AILV1                0x0700


// 0x000042e8   Additional interrupt level register 1
#define ITC_ATILV1                      (*(volatile unsigned short*)0x000042e8)
    // [2:0]    ADC renge int level
    #define ITC_ATILV1_AILV2                0x0007

    // [10:8]   ADC end int level
    #define ITC_ATILV1_AILV3                0x0700


// 0x000042ea   Additional interrupt level register 2
#define ITC_ATILV2                      (*(volatile unsigned short*)0x000042ea)
    // [2:0]    RTC int level
    #define ITC_ATILV2_AILV4                0x0007

    // [10:8]   8bit timer Ch0 int level
    #define ITC_ATILV2_AILV5                0x0700


// 0x000042ec   Additional interrupt level register 3
#define ITC_ATILV3                      (*(volatile unsigned short*)0x000042ec)
    // [2:0]    8bit timer Ch1 int level
    #define ITC_ATILV3_AILV6                0x0007

    // [10:8]   8bit timer Ch2 int level
    #define ITC_ATILV3_AILV7                0x0700


// 0x000042ee   Additional interrupt level register 4
#define ITC_ATILV4                      (*(volatile unsigned short*)0x000042ee)
    // [2:0]    8bit timer Ch3 int level
    #define ITC_ATILV4_AILV8                0x0007

    // [10:8]   LCDC int level
    #define ITC_ATILV4_AILV9                0x0700


// 0x000042f0   Additional interrupt level register 5
#define ITC_ATILV5                      (*(volatile unsigned short*)0x000042f0)
    // [2:0]    SPI Ch1 int level
    #define ITC_ATILV5_AILV10               0x0007

    // [10:8]   USB int level
    #define ITC_ATILV5_AILV11               0x0700


// 0x000042f2   Additional interrupt level register 6
#define ITC_ATILV6                      (*(volatile unsigned short*)0x000042f2)
    // [2:0]    I2S transmit int level
    #define ITC_ATILV6_AILV12               0x0007

    // [10:8]   I2S receive int level
    #define ITC_ATILV6_AILV13               0x0700


// 0x000042f4   Additional interrupt level register 7
#define ITC_ATILV7                      (*(volatile unsigned short*)0x000042f4)
    // [2:0]    REMC int level
    #define ITC_ATILV7_AILV14               0x0007


// 0x000042f6   Test status register
#define ITC_TSTSTS                      (*(volatile unsigned short*)0x000042f6)
    // [4:0]    ITC vector request
    #define ITC_TSTSTS_VEC                  0x001f

    // [10:8]   ITC priority request
    #define ITC_TSTSTS_IPL                  0x0700

    // [11]     ITC wake-up request
    #define ITC_TSTSTS_WAK                  0x0800

    // [12]     ITC interrupt request
    #define ITC_TSTSTS_INT                  0x1000


// 0x00004300   Interrupt factor register
#define ITC_ITFT                        (*(volatile unsigned short*)0x00004300)
    // [0]      eint0 factor
    #define ITC_ITFT_EIFT0                  0x0001

    // [1]      eint1 factor
    #define ITC_ITFT_EIFT1                  0x0002

    // [2]      eint2 factor
    #define ITC_ITFT_EIFT2                  0x0004

    // [3]      eint3 factor
    #define ITC_ITFT_EIFT3                  0x0008

    // [4]      eint4 factor
    #define ITC_ITFT_EIFT4                  0x0010

    // [5]      eint5 factor
    #define ITC_ITFT_EIFT5                  0x0020

    // [6]      eint6 factor
    #define ITC_ITFT_EIFT6                  0x0040

    // [7]      eint7 factor
    #define ITC_ITFT_EIFT7                  0x0080

    // [8]      Timer Ch0 factor
    #define ITC_ITFT_IIFT0                  0x0100

    // [9]      Timer Ch1 factor
    #define ITC_ITFT_IIFT1                  0x0200

    // [10]     Timer Ch2 factor
    #define ITC_ITFT_IIFT2                  0x0400

    // [11]     Timer Ch3 factor
    #define ITC_ITFT_IIFT3                  0x0800

    // [12]     UART Ch0 factor
    #define ITC_ITFT_IIFT4                  0x1000

    // [13]     UART Ch1 factor
    #define ITC_ITFT_IIFT5                  0x2000

    // [14]     SPI factor
    #define ITC_ITFT_IIFT6                  0x4000

    // [15]     I2C factor
    #define ITC_ITFT_IIFT7                  0x8000


// 0x00004302   Interrupt enable register
#define ITC_ITEN                        (*(volatile unsigned short*)0x00004302)
    // [0]      eint0 enable
    #define ITC_ITEN_EIEN0                  0x0001

    // [1]      eint1 enable
    #define ITC_ITEN_EIEN1                  0x0002

    // [2]      eint2 enable
    #define ITC_ITEN_EIEN2                  0x0004

    // [3]      eint3 enable
    #define ITC_ITEN_EIEN3                  0x0008

    // [4]      eint4 enable
    #define ITC_ITEN_EIEN4                  0x0010

    // [5]      eint5 enable
    #define ITC_ITEN_EIEN5                  0x0020

    // [6]      eint6 enable
    #define ITC_ITEN_EIEN6                  0x0040

    // [7]      eint7 enable
    #define ITC_ITEN_EIEN7                  0x0080

    // [8]      Timer Ch0 enable
    #define ITC_ITEN_IIEN0                  0x0100

    // [9]      Timer Ch1 enable
    #define ITC_ITEN_IIEN1                  0x0200

    // [10]     Timer Ch2 enable
    #define ITC_ITEN_IIEN2                  0x0400

    // [11]     Timer Ch3 enable
    #define ITC_ITEN_IIEN3                  0x0800

    // [12]     UART Ch0 enable
    #define ITC_ITEN_IIEN4                  0x1000

    // [13]     UART Ch1 enable
    #define ITC_ITEN_IIEN5                  0x2000

    // [14]     SPI enable
    #define ITC_ITEN_IIEN6                  0x4000

    // [15]     I2C enable
    #define ITC_ITEN_IIEN7                  0x8000


// 0x00004304   Interrupt control register
#define ITC_ITCTL                       (*(volatile unsigned short*)0x00004304)
    // [0]      int function ebable
    #define ITC_ITCTL_ITEN                  0x0001

    // [7]      int test enable
    #define ITC_ITCTL_ITTST                 0x0080


// 0x00004306   External interrupt level register 0
#define ITC_ITELV0                      (*(volatile unsigned short*)0x00004306)
    // [2:0]    eint0 int level
    #define ITC_ITELV0_EILV0                0x0007

    // [4]      eint0 trigger mode
    #define ITC_ITELV0_EITG0                0x0010

    // [5]      eint0 trigger polarity
    #define ITC_ITELV0_EITP0                0x0020

    // [10:8]   eint1 int level
    #define ITC_ITELV0_EILV1                0x0700

    // [12]     eint1 trigger mode
    #define ITC_ITELV0_EITG1                0x1000

    // [13]     eint1 trigger polarity
    #define ITC_ITELV0_EITP1                0x2000


// 0x00004308   External interrupt level register 1
#define ITC_ITELV1                      (*(volatile unsigned short*)0x00004308)
    // [2:0]    eint2 int level
    #define ITC_ITELV1_EILV2                0x0007

    // [4]      eint2 trigger mode
    #define ITC_ITELV1_EITG2                0x0010

    // [5]      eint2 trigger polarity
    #define ITC_ITELV1_EITP2                0x0020

    // [10:8]   eint3 int level
    #define ITC_ITELV1_EILV3                0x0700

    // [12]     eint3 trigger mode
    #define ITC_ITELV1_EITG3                0x1000

    // [13]     eint3 trigger polarity
    #define ITC_ITELV1_EITP3                0x2000


// 0x0000430a   External interrupt level register 2
#define ITC_ITELV2                      (*(volatile unsigned short*)0x0000430a)
    // [2:0]    eint4 int level
    #define ITC_ITELV2_EILV4                0x0007

    // [4]      eint4 trigger mode
    #define ITC_ITELV2_EITG4                0x0010

    // [5]      eint4 trigger polarity
    #define ITC_ITELV2_EITP4                0x0020

    // [10:8]   eint5 int level
    #define ITC_ITELV2_EILV5                0x0700

    // [12]     eint5 trigger mode
    #define ITC_ITELV2_EITG5                0x1000

    // [13]     eint5 trigger polarity
    #define ITC_ITELV2_EITP5                0x2000


// 0x0000430c   External interrupt level register 3
#define ITC_ITELV3                      (*(volatile unsigned short*)0x0000430c)
    // [2:0]    eint6 int level
    #define ITC_ITELV3_EILV6                0x0007

    // [4]      eint6 trigger mode
    #define ITC_ITELV3_EITG6                0x0010

    // [5]      eint6 trigger polarity
    #define ITC_ITELV3_EITP6                0x0020

    // [10:8]   eint7 int level
    #define ITC_ITELV3_EILV7                0x0700

    // [12]     eint7 trigger mode
    #define ITC_ITELV3_EITG7                0x1000

    // [13]     eint7 trigger polarity
    #define ITC_ITELV3_EITP7                0x2000


// 0x0000430e   Internal interrupt level register 0
#define ITC_ITILV0                      (*(volatile unsigned short*)0x0000430e)
    // [2:0]    Timer Ch0 int level
    #define ITC_ITILV0_IILV0                0x0007

    // [10:8]   Timer Ch1 int level
    #define ITC_ITILV0_IILV1                0x0700


// 0x00004310   Internal interrupt level register 1
#define ITC_ITILV1                      (*(volatile unsigned short*)0x00004310)
    // [2:0]    Timer Ch2 int level
    #define ITC_ITILV1_IILV2                0x0007

    // [10:8]   Timer Ch3 int level
    #define ITC_ITILV1_IILV3                0x0700


// 0x00004312   Internal interrupt level register 2
#define ITC_ITILV2                      (*(volatile unsigned short*)0x00004312)
    // [2:0]    UART Ch0 int level
    #define ITC_ITILV2_IILV4                0x0007

    // [10:8]   UART Ch1 int level
    #define ITC_ITILV2_IILV5                0x0700


// 0x00004314   Internal interrupt level register 3
#define ITC_ITILV3                      (*(volatile unsigned short*)0x00004314)
    // [2:0]    SPI int level
    #define ITC_ITILV3_IILV6                0x0007

    // [10:8]   I2C int level
    #define ITC_ITILV3_IILV7                0x0700


// 0x0000431c   Interrupt configration ID
#define ITC_ICID0                       (*(volatile unsigned short*)0x0000431c)
    // [0]      16bit Timer Ch0
    #define ITC_ICID0_ICID0                 0x0001

    // [1]      16bit Timer Ch1
    #define ITC_ICID0_ICID1                 0x0002

    // [2]      ADC range
    #define ITC_ICID0_ICID2                 0x0004

    // [3]      ADC end
    #define ITC_ICID0_ICID3                 0x0008

    // [4]      RTC
    #define ITC_ICID0_ICID4                 0x0010

    // [5]      8bit timer Ch0
    #define ITC_ICID0_ICID5                 0x0020

    // [6]      8bit timer Ch1
    #define ITC_ICID0_ICID6                 0x0040

    // [7]      8bit timer Ch2
    #define ITC_ICID0_ICID7                 0x0080

    // [8]      8bit timer Ch3
    #define ITC_ICID0_ICID8                 0x0100

    // [9]      LCDC
    #define ITC_ICID0_ICID9                 0x0200

    // [10]     SPI Ch1
    #define ITC_ICID0_ICID10                0x0400

    // [11]     USB
    #define ITC_ICID0_ICID11                0x0800

    // [12]     I2S transmit
    #define ITC_ICID0_ICID12                0x1000

    // [13]     I2S receive
    #define ITC_ICID0_ICID13                0x2000

    // [14]     REMC
    #define ITC_ICID0_ICID14                0x4000


// 0x0000431e   Interrupt configration ID
#define ITC_ICID1                       (*(volatile unsigned short*)0x0000431e)
    // [0]      eint0
    #define ITC_ICID1_ICID0                 0x0001

    // [1]      eint1
    #define ITC_ICID1_ICID1                 0x0002

    // [2]      eint2
    #define ITC_ICID1_ICID2                 0x0004

    // [3]      eint3
    #define ITC_ICID1_ICID3                 0x0008

    // [4]      eint4
    #define ITC_ICID1_ICID4                 0x0010

    // [5]      eint5
    #define ITC_ICID1_ICID5                 0x0020

    // [6]      eint6
    #define ITC_ICID1_ICID6                 0x0040

    // [7]      eint7
    #define ITC_ICID1_ICID7                 0x0080

    // [8]      Timer Ch0
    #define ITC_ICID1_ICID8                 0x0100

    // [9]      Timer Ch1
    #define ITC_ICID1_ICID9                 0x0200

    // [10]     Timer Ch2
    #define ITC_ICID1_ICID10                0x0400

    // [11]     Timer Ch3
    #define ITC_ICID1_ICID11                0x0800

    // [12]     UART Ch0
    #define ITC_ICID1_ICID12                0x1000

    // [13]     UART Ch1
    #define ITC_ICID1_ICID13                0x2000

    // [14]     SPI Ch0
    #define ITC_ICID1_ICID14                0x4000

    // [15]     I2C
    #define ITC_ICID1_ICID15                0x8000


/*****************************************************************************
    SPI0    (0x00004320)    SPI Ch0 Controller
*****************************************************************************/

// 0x00004320   SPI Status register
#define SPI0_ST                         (*(volatile unsigned short*)0x00004320)
    // [0]      Transmit data buffer empty flag
    #define SPI0_ST_SPTBE                   0x0001

    // [1]      Receive data buffer full flag
    #define SPI0_ST_SPRBF                   0x0002

    // [2]      Transfer busy flag(master)
    #define SPI0_ST_SPBSY                   0x0004


// 0x00004322   SPI Transmit Data register
#define SPI0_TXD                        (*(volatile unsigned short*)0x00004322)
    // [7:0]    SPI transmit data buffer
    #define SPI0_TXD_SPTDB                  0x00ff


// 0x00004324   SPI Receive Data register
#define SPI0_RXD                        (*(volatile unsigned short*)0x00004324)
    // [7:0]    SPI receive data buffer
    #define SPI0_RXD_SPRDB                  0x00ff


// 0x00004326   SPI Control register
#define SPI0_CTL                        (*(volatile unsigned short*)0x00004326)
    // [0]      SPI enable
    #define SPI0_CTL_SPEN                   0x0001

    // [1]      Master/Slave mode select
    #define SPI0_CTL_MSSL                   0x0002

    // [2]      Clock polarity select
    #define SPI0_CTL_CPOL                   0x0004

    // [3]      Clock phase selct
    #define SPI0_CTL_CPHA                   0x0008

    // [4]      Transmit data buffer empty int. enable
    #define SPI0_CTL_SPTIE                  0x0010

    // [5]      Receive data buffer full int. enable
    #define SPI0_CTL_SPRIE                  0x0020


/*****************************************************************************
    I2C     (0x00004340)    I2C Controller
*****************************************************************************/

// 0x00004340   I2C Enable register
#define I2C_EN                          (*(volatile unsigned short*)0x00004340)
    // [0]      I2C Enable
    #define I2C_EN_I2CEN                    0x0001


// 0x00004342   I2C Control register
#define I2C_CTL                         (*(volatile unsigned short*)0x00004342)
    // [0]      Start control
    #define I2C_CTL_STRT                    0x0001

    // [1]      Stop control
    #define I2C_CTL_STP                     0x0002

    // [4]      Noise remove on/ogg
    #define I2C_CTL_NSERM                   0x0010

    // [5]      Clock stretch on/off
    #define I2C_CTL_CSTR                    0x0020

    // [8]      Transmit busy flag
    #define I2C_CTL_TBUSY                   0x0100

    // [9]      Receive busy flag
    #define I2C_CTL_RBUSY                   0x0200


// 0x00004344   I2C Data register
#define I2C_DAT                         (*(volatile unsigned short*)0x00004344)
    // [7:0]    Receive/transmit data
    #define I2C_DAT_RTDT                    0x00ff

    // [8]      Receive/transmit ACK
    #define I2C_DAT_RTACK                   0x0100

    // [9]      Transmit execution
    #define I2C_DAT_TXE                     0x0200

    // [10]     Receive execution
    #define I2C_DAT_RXE                     0x0400

    // [11]     Receive buffer ready
    #define I2C_DAT_RBRDY                   0x0800


// 0x00004346   I2C Interrupt Control register
#define I2C_ICTL                        (*(volatile unsigned short*)0x00004346)
    // [0]      Trasmit interrupt enable
    #define I2C_ICTL_TINTE                  0x0001

    // [1]      Receive interrupt enable
    #define I2C_ICTL_RINTE                  0x0002


/*****************************************************************************
    EGPIO   (0x00004400)    Extended Ports
*****************************************************************************/

// 0x00004400   P0 port data register
#define EGPIO_P0_DATA                   (*(volatile unsigned char*)0x00004400)
    // [0]      P00 port data
    #define EGPIO_P0_DATA_P00D              0x01

    // [1]      P01 port data
    #define EGPIO_P0_DATA_P01D              0x02

    // [2]      P02 port data
    #define EGPIO_P0_DATA_P02D              0x04

    // [3]      P03 port data
    #define EGPIO_P0_DATA_P03D              0x08

    // [4]      P04 port data
    #define EGPIO_P0_DATA_P04D              0x10

    // [5]      P05 port data
    #define EGPIO_P0_DATA_P05D              0x20

    // [6]      P06 port data
    #define EGPIO_P0_DATA_P06D              0x40

    // [7]      P07 port data
    #define EGPIO_P0_DATA_P07D              0x80


// 0x00004401   P0 I/O control register
#define EGPIO_P0_IOC                    (*(volatile unsigned char*)0x00004401)
    // [0]      P00 I/O control
    #define EGPIO_P0_IOC_IOC00              0x01

    // [1]      P01 I/O control
    #define EGPIO_P0_IOC_IOC01              0x02

    // [2]      P02 I/O control
    #define EGPIO_P0_IOC_IOC02              0x04

    // [3]      P03 I/O control
    #define EGPIO_P0_IOC_IOC03              0x08

    // [4]      P04 I/O control
    #define EGPIO_P0_IOC_IOC04              0x10

    // [5]      P05 I/O control
    #define EGPIO_P0_IOC_IOC05              0x20

    // [6]      P06 I/O control
    #define EGPIO_P0_IOC_IOC06              0x40

    // [7]      P07 I/O control
    #define EGPIO_P0_IOC_IOC07              0x80


// 0x00004402   P1 port data register
#define EGPIO_P1_DATA                   (*(volatile unsigned char*)0x00004402)
    // [0]      P10 port data
    #define EGPIO_P1_DATA_P10D              0x01

    // [1]      P11 port data
    #define EGPIO_P1_DATA_P11D              0x02

    // [2]      P12 port data
    #define EGPIO_P1_DATA_P12D              0x04

    // [3]      P13 port data
    #define EGPIO_P1_DATA_P13D              0x08

    // [4]      P14 port data
    #define EGPIO_P1_DATA_P14D              0x10

    // [5]      P15 port data
    #define EGPIO_P1_DATA_P15D              0x20

    // [6]      P16 port data
    #define EGPIO_P1_DATA_P16D              0x40

    // [7]      P17 port data
    #define EGPIO_P1_DATA_P17D              0x80


// 0x00004403   P1 I/O control register
#define EGPIO_P1_IOC                    (*(volatile unsigned char*)0x00004403)
    // [0]      P10 I/O control
    #define EGPIO_P1_IOC_IOC10              0x01

    // [1]      P11 I/O control
    #define EGPIO_P1_IOC_IOC11              0x02

    // [2]      P12 I/O control
    #define EGPIO_P1_IOC_IOC12              0x04

    // [3]      P13 I/O control
    #define EGPIO_P1_IOC_IOC13              0x08

    // [4]      P14 I/O control
    #define EGPIO_P1_IOC_IOC14              0x10

    // [5]      P15 I/O control
    #define EGPIO_P1_IOC_IOC15              0x20

    // [6]      P16 I/O control
    #define EGPIO_P1_IOC_IOC16              0x40

    // [7]      P17 I/O control
    #define EGPIO_P1_IOC_IOC17              0x80


// 0x00004404   P2 port data register
#define EGPIO_P2_DATA                   (*(volatile unsigned char*)0x00004404)
    // [0]      P20 port data
    #define EGPIO_P2_DATA_P20D              0x01

    // [1]      P21 port data
    #define EGPIO_P2_DATA_P21D              0x02

    // [2]      P22 port data
    #define EGPIO_P2_DATA_P22D              0x04

    // [3]      P23 port data
    #define EGPIO_P2_DATA_P23D              0x08

    // [4]      P24 port data
    #define EGPIO_P2_DATA_P24D              0x10

    // [5]      P25 port data
    #define EGPIO_P2_DATA_P25D              0x20

    // [6]      P26 port data
    #define EGPIO_P2_DATA_P26D              0x40

    // [7]      P27 port data
    #define EGPIO_P2_DATA_P27D              0x80


// 0x00004405   P2 I/O control register
#define EGPIO_P2_IOC                    (*(volatile unsigned char*)0x00004405)
    // [0]      P20 I/O control
    #define EGPIO_P2_IOC_IOC20              0x01

    // [1]      P21 I/O control
    #define EGPIO_P2_IOC_IOC21              0x02

    // [2]      P22 I/O control
    #define EGPIO_P2_IOC_IOC22              0x04

    // [3]      P23 I/O control
    #define EGPIO_P2_IOC_IOC23              0x08

    // [4]      P24 I/O control
    #define EGPIO_P2_IOC_IOC24              0x10

    // [5]      P25 I/O control
    #define EGPIO_P2_IOC_IOC25              0x20

    // [6]      P26 I/O control
    #define EGPIO_P2_IOC_IOC26              0x40

    // [7]      P27 I/O control
    #define EGPIO_P2_IOC_IOC27              0x80


// 0x00004406   P3 port data register
#define EGPIO_P3_DATA                   (*(volatile unsigned char*)0x00004406)
    // [0]      P30 port data
    #define EGPIO_P3_DATA_P30D              0x01

    // [1]      P31 port data
    #define EGPIO_P3_DATA_P31D              0x02

    // [2]      P32 port data
    #define EGPIO_P3_DATA_P32D              0x04

    // [3]      P33 port data
    #define EGPIO_P3_DATA_P33D              0x08

    // [4]      P34 port data
    #define EGPIO_P3_DATA_P34D              0x10

    // [5]      P35 port data
    #define EGPIO_P3_DATA_P35D              0x20

    // [6]      P36 port data
    #define EGPIO_P3_DATA_P36D              0x40

    // [7]      P37 port data
    #define EGPIO_P3_DATA_P37D              0x80


// 0x00004407   P3 I/O control register
#define EGPIO_P3_IOC                    (*(volatile unsigned char*)0x00004407)
    // [0]      P30 I/O control
    #define EGPIO_P3_IOC_IOC30              0x01

    // [1]      P31 I/O control
    #define EGPIO_P3_IOC_IOC31              0x02

    // [2]      P32 I/O control
    #define EGPIO_P3_IOC_IOC32              0x04

    // [3]      P33 I/O control
    #define EGPIO_P3_IOC_IOC33              0x08

    // [4]      P34 I/O control
    #define EGPIO_P3_IOC_IOC34              0x10

    // [5]      P35 I/O control
    #define EGPIO_P3_IOC_IOC35              0x20

    // [6]      P36 I/O control
    #define EGPIO_P3_IOC_IOC36              0x40

    // [7]      P37 I/O control
    #define EGPIO_P3_IOC_IOC37              0x80


// 0x00004408   P4 port data register
#define EGPIO_P4_DATA                   (*(volatile unsigned char*)0x00004408)
    // [0]      P40 port data
    #define EGPIO_P4_DATA_P40D              0x01

    // [1]      P41 port data
    #define EGPIO_P4_DATA_P41D              0x02

    // [2]      P42 port data
    #define EGPIO_P4_DATA_P42D              0x04

    // [3]      P43 port data
    #define EGPIO_P4_DATA_P43D              0x08

    // [4]      P44 port data
    #define EGPIO_P4_DATA_P44D              0x10

    // [5]      P45 port data
    #define EGPIO_P4_DATA_P45D              0x20

    // [6]      P46 port data
    #define EGPIO_P4_DATA_P46D              0x40

    // [7]      P47 port data
    #define EGPIO_P4_DATA_P47D              0x80


// 0x00004409   P4 I/O control register
#define EGPIO_P4_IOC                    (*(volatile unsigned char*)0x00004409)
    // [0]      P40 I/O control
    #define EGPIO_P4_IOC_IOC40              0x01

    // [1]      P41 I/O control
    #define EGPIO_P4_IOC_IOC41              0x02

    // [2]      P42 I/O control
    #define EGPIO_P4_IOC_IOC42              0x04

    // [3]      P43 I/O control
    #define EGPIO_P4_IOC_IOC43              0x08

    // [4]      P44 I/O control
    #define EGPIO_P4_IOC_IOC44              0x10

    // [5]      P45 I/O control
    #define EGPIO_P4_IOC_IOC45              0x20

    // [6]      P46 I/O control
    #define EGPIO_P4_IOC_IOC46              0x40

    // [7]      P47 I/O control
    #define EGPIO_P4_IOC_IOC47              0x80


// 0x0000440a   P5 port data register
#define EGPIO_P5_DATA                   (*(volatile unsigned char*)0x0000440a)
    // [0]      P50 port data
    #define EGPIO_P5_DATA_P50D              0x01

    // [1]      P51 port data
    #define EGPIO_P5_DATA_P51D              0x02

    // [2]      P52 port data
    #define EGPIO_P5_DATA_P52D              0x04

    // [3]      P53 port data
    #define EGPIO_P5_DATA_P53D              0x08

    // [4]      P54 port data
    #define EGPIO_P5_DATA_P54D              0x10

    // [5]      P55 port data
    #define EGPIO_P5_DATA_P55D              0x20

    // [6]      P56 port data
    #define EGPIO_P5_DATA_P56D              0x40

    // [7]      P57 port data
    #define EGPIO_P5_DATA_P57D              0x80


// 0x0000440b   P5 I/O control register
#define EGPIO_P5_IOC                    (*(volatile unsigned char*)0x0000440b)
    // [0]      P50 I/O control
    #define EGPIO_P5_IOC_IOC50              0x01

    // [1]      P51 I/O control
    #define EGPIO_P5_IOC_IOC51              0x02

    // [2]      P52 I/O control
    #define EGPIO_P5_IOC_IOC52              0x04

    // [3]      P53 I/O control
    #define EGPIO_P5_IOC_IOC53              0x08

    // [4]      P54 I/O control
    #define EGPIO_P5_IOC_IOC54              0x10

    // [5]      P55 I/O control
    #define EGPIO_P5_IOC_IOC55              0x20

    // [6]      P56 I/O control
    #define EGPIO_P5_IOC_IOC56              0x40

    // [7]      P57 I/O control
    #define EGPIO_P5_IOC_IOC57              0x80


// 0x0000440c   P6 port data register
#define EGPIO_P6_DATA                   (*(volatile unsigned char*)0x0000440c)
    // [0]      P60 port data
    #define EGPIO_P6_DATA_P60D              0x01

    // [1]      P61 port data
    #define EGPIO_P6_DATA_P61D              0x02

    // [2]      P62 port data
    #define EGPIO_P6_DATA_P62D              0x04

    // [3]      P63 port data
    #define EGPIO_P6_DATA_P63D              0x08

    // [4]      P64 port data
    #define EGPIO_P6_DATA_P64D              0x10

    // [5]      P65 port data
    #define EGPIO_P6_DATA_P65D              0x20

    // [6]      P66 port data
    #define EGPIO_P6_DATA_P66D              0x40

    // [7]      P67 port data
    #define EGPIO_P6_DATA_P67D              0x80


// 0x0000440d   P6 I/O control register
#define EGPIO_P6_IOC                    (*(volatile unsigned char*)0x0000440d)
    // [0]      P60 I/O control
    #define EGPIO_P6_IOC_IOC60              0x01

    // [1]      P61 I/O control
    #define EGPIO_P6_IOC_IOC61              0x02

    // [2]      P62 I/O control
    #define EGPIO_P6_IOC_IOC62              0x04

    // [3]      P63 I/O control
    #define EGPIO_P6_IOC_IOC63              0x08

    // [4]      P64 I/O control
    #define EGPIO_P6_IOC_IOC64              0x10

    // [5]      P65 I/O control
    #define EGPIO_P6_IOC_IOC65              0x20

    // [6]      P66 I/O control
    #define EGPIO_P6_IOC_IOC66              0x40

    // [7]      P67 I/O control
    #define EGPIO_P6_IOC_IOC67              0x80


// 0x0000440e   P7 port data register
#define EGPIO_P7_DATA                   (*(volatile unsigned char*)0x0000440e)
    // [0]      P70 port data
    #define EGPIO_P7_DATA_P70D              0x01

    // [1]      P71 port data
    #define EGPIO_P7_DATA_P71D              0x02

    // [2]      P72 port data
    #define EGPIO_P7_DATA_P72D              0x04

    // [3]      P73 port data
    #define EGPIO_P7_DATA_P73D              0x08

    // [4]      P74 port data
    #define EGPIO_P7_DATA_P74D              0x10

    // [5]      P75 port data
    #define EGPIO_P7_DATA_P75D              0x20

    // [6]      P76 port data
    #define EGPIO_P7_DATA_P76D              0x40

    // [7]      P77 port data
    #define EGPIO_P7_DATA_P77D              0x80


// 0x0000440f   P7 I/O control register
#define EGPIO_P7_IOC                    (*(volatile unsigned char*)0x0000440f)
    // [0]      P70 I/O control
    #define EGPIO_P7_IOC_IOC70              0x01

    // [1]      P71 I/O control
    #define EGPIO_P7_IOC_IOC71              0x02

    // [2]      P72 I/O control
    #define EGPIO_P7_IOC_IOC72              0x04

    // [3]      P73 I/O control
    #define EGPIO_P7_IOC_IOC73              0x08

    // [4]      P74 I/O control
    #define EGPIO_P7_IOC_IOC74              0x10

    // [5]      P75 I/O control
    #define EGPIO_P7_IOC_IOC75              0x20

    // [6]      P76 I/O control
    #define EGPIO_P7_IOC_IOC76              0x40

    // [7]      P77 I/O control
    #define EGPIO_P7_IOC_IOC77              0x80


// 0x00004410   P8 port data register
#define EGPIO_P8_DATA                   (*(volatile unsigned char*)0x00004410)
    // [0]      P80 port data
    #define EGPIO_P8_DATA_P80D              0x01

    // [1]      P81 port data
    #define EGPIO_P8_DATA_P81D              0x02

    // [2]      P82 port data
    #define EGPIO_P8_DATA_P82D              0x04

    // [3]      P83 port data
    #define EGPIO_P8_DATA_P83D              0x08

    // [4]      P84 port data
    #define EGPIO_P8_DATA_P84D              0x10

    // [5]      P85 port data
    #define EGPIO_P8_DATA_P85D              0x20

    // [6]      P86 port data
    #define EGPIO_P8_DATA_P86D              0x40

    // [7]      P87 port data
    #define EGPIO_P8_DATA_P87D              0x80


// 0x00004411   P8 I/O control register
#define EGPIO_P8_IOC                    (*(volatile unsigned char*)0x00004411)
    // [0]      P80 I/O control
    #define EGPIO_P8_IOC_IOC80              0x01

    // [1]      P81 I/O control
    #define EGPIO_P8_IOC_IOC81              0x02

    // [2]      P82 I/O control
    #define EGPIO_P8_IOC_IOC82              0x04

    // [3]      P83 I/O control
    #define EGPIO_P8_IOC_IOC83              0x08

    // [4]      P84 I/O control
    #define EGPIO_P8_IOC_IOC84              0x10

    // [5]      P85 I/O control
    #define EGPIO_P8_IOC_IOC85              0x20

    // [6]      P86 I/O control
    #define EGPIO_P8_IOC_IOC86              0x40

    // [7]      P87 I/O control
    #define EGPIO_P8_IOC_IOC87              0x80


// 0x00004412   P9 port data register
#define EGPIO_P9_DATA                   (*(volatile unsigned char*)0x00004412)
    // [0]      P90 port data
    #define EGPIO_P9_DATA_P90D              0x01

    // [1]      P91 port data
    #define EGPIO_P9_DATA_P91D              0x02

    // [2]      P92 port data
    #define EGPIO_P9_DATA_P92D              0x04

    // [3]      P93 port data
    #define EGPIO_P9_DATA_P93D              0x08

    // [4]      P94 port data
    #define EGPIO_P9_DATA_P94D              0x10

    // [5]      P95 port data
    #define EGPIO_P9_DATA_P95D              0x20

    // [6]      P96 port data
    #define EGPIO_P9_DATA_P96D              0x40

    // [7]      P97 port data
    #define EGPIO_P9_DATA_P97D              0x80


// 0x00004413   P9 I/O control register
#define EGPIO_P9_IOC                    (*(volatile unsigned char*)0x00004413)
    // [0]      P90 I/O control
    #define EGPIO_P9_IOC_IOC90              0x01

    // [1]      P91 I/O control
    #define EGPIO_P9_IOC_IOC91              0x02

    // [2]      P92 I/O control
    #define EGPIO_P9_IOC_IOC92              0x04

    // [3]      P93 I/O control
    #define EGPIO_P9_IOC_IOC93              0x08

    // [4]      P94 I/O control
    #define EGPIO_P9_IOC_IOC94              0x10

    // [5]      P95 I/O control
    #define EGPIO_P9_IOC_IOC95              0x20

    // [6]      P96 I/O control
    #define EGPIO_P9_IOC_IOC96              0x40

    // [7]      P97 I/O control
    #define EGPIO_P9_IOC_IOC97              0x80


// 0x00004414   PA port data register
#define EGPIO_PA_DATA                   (*(volatile unsigned char*)0x00004414)
    // [0]      PA0 port data
    #define EGPIO_PA_DATA_PA0D              0x01

    // [1]      PA1 port data
    #define EGPIO_PA_DATA_PA1D              0x02

    // [2]      PA2 port data
    #define EGPIO_PA_DATA_PA2D              0x04

    // [3]      PA3 port data
    #define EGPIO_PA_DATA_PA3D              0x08

    // [4]      PA4 port data
    #define EGPIO_PA_DATA_PA4D              0x10

    // [5]      PA5 port data
    #define EGPIO_PA_DATA_PA5D              0x20

    // [6]      PA6 port data
    #define EGPIO_PA_DATA_PA6D              0x40

    // [7]      PA7 port data
    #define EGPIO_PA_DATA_PA7D              0x80


// 0x00004415   PA I/O control register
#define EGPIO_PA_IOC                    (*(volatile unsigned char*)0x00004415)
    // [0]      PA0 I/O control
    #define EGPIO_PA_IOC_IOCA0              0x01

    // [1]      PA1 I/O control
    #define EGPIO_PA_IOC_IOCA1              0x02

    // [2]      PA2 I/O control
    #define EGPIO_PA_IOC_IOCA2              0x04

    // [3]      PA3 I/O control
    #define EGPIO_PA_IOC_IOCA3              0x08

    // [4]      PA4 I/O control
    #define EGPIO_PA_IOC_IOCA4              0x10

    // [5]      PA5 I/O control
    #define EGPIO_PA_IOC_IOCA5              0x20

    // [6]      PA6 I/O control
    #define EGPIO_PA_IOC_IOCA6              0x40

    // [7]      PA7 I/O control
    #define EGPIO_PA_IOC_IOCA7              0x80


// 0x00004416   PB port data register
#define EGPIO_PB_DATA                   (*(volatile unsigned char*)0x00004416)
    // [0]      PB0 port data
    #define EGPIO_PB_DATA_PB0D              0x01

    // [1]      PB1 port data
    #define EGPIO_PB_DATA_PB1D              0x02

    // [2]      PB2 port data
    #define EGPIO_PB_DATA_PB2D              0x04

    // [3]      PB3 port data
    #define EGPIO_PB_DATA_PB3D              0x08

    // [4]      PB4 port data
    #define EGPIO_PB_DATA_PB4D              0x10

    // [5]      PB5 port data
    #define EGPIO_PB_DATA_PB5D              0x20

    // [6]      PB6 port data
    #define EGPIO_PB_DATA_PB6D              0x40

    // [7]      PB7 port data
    #define EGPIO_PB_DATA_PB7D              0x80


// 0x00004417   PB I/O control register
#define EGPIO_PB_IOC                    (*(volatile unsigned char*)0x00004417)
    // [0]      PB0 I/O control
    #define EGPIO_PB_IOC_IOCB0              0x01

    // [1]      PB1 I/O control
    #define EGPIO_PB_IOC_IOCB1              0x02

    // [2]      PB2 I/O control
    #define EGPIO_PB_IOC_IOCB2              0x04

    // [3]      PB3 I/O control
    #define EGPIO_PB_IOC_IOCB3              0x08

    // [4]      PB4 I/O control
    #define EGPIO_PB_IOC_IOCB4              0x10

    // [5]      PB5 I/O control
    #define EGPIO_PB_IOC_IOCB5              0x20

    // [6]      PB6 I/O control
    #define EGPIO_PB_IOC_IOCB6              0x40

    // [7]      PB7 I/O control
    #define EGPIO_PB_IOC_IOCB7              0x80


// 0x00004418   PC port data register
#define EGPIO_PC_DATA                   (*(volatile unsigned char*)0x00004418)
    // [0]      PC0 port data
    #define EGPIO_PC_DATA_PC0D              0x01

    // [1]      PC1 port data
    #define EGPIO_PC_DATA_PC1D              0x02

    // [2]      PC2 port data
    #define EGPIO_PC_DATA_PC2D              0x04

    // [3]      PC3 port data
    #define EGPIO_PC_DATA_PC3D              0x08

    // [4]      PC4 port data
    #define EGPIO_PC_DATA_PC4D              0x10

    // [5]      PC5 port data
    #define EGPIO_PC_DATA_PC5D              0x20

    // [6]      PC6 port data
    #define EGPIO_PC_DATA_PC6D              0x40

    // [7]      PC7 port data
    #define EGPIO_PC_DATA_PC7D              0x80


// 0x00004419   PC I/O control register
#define EGPIO_PC_IOC                    (*(volatile unsigned char*)0x00004419)
    // [0]      PC0 I/O control
    #define EGPIO_PC_IOC_IOCC0              0x01

    // [1]      PC1 I/O control
    #define EGPIO_PC_IOC_IOCC1              0x02

    // [2]      PC2 I/O control
    #define EGPIO_PC_IOC_IOCC2              0x04

    // [3]      PC3 I/O control
    #define EGPIO_PC_IOC_IOCC3              0x08

    // [4]      PC4 I/O control
    #define EGPIO_PC_IOC_IOCC4              0x10

    // [5]      PC5 I/O control
    #define EGPIO_PC_IOC_IOCC5              0x20

    // [6]      PC6 I/O control
    #define EGPIO_PC_IOC_IOCC6              0x40

    // [7]      PC7 I/O control
    #define EGPIO_PC_IOC_IOCC7              0x80


// 0x00004420   P00-P03 function select register
#define EGPIO_P0_03_CFP                 (*(volatile unsigned char*)0x00004420)
    // [1:0]    P00 port extended function
    #define EGPIO_P0_03_CFP_CFP00           0x03

    // [3:2]    P01 port extended function
    #define EGPIO_P0_03_CFP_CFP01           0x0c

    // [5:4]    P02 port extended function
    #define EGPIO_P0_03_CFP_CFP02           0x30

    // [7:6]    P03 port extended function
    #define EGPIO_P0_03_CFP_CFP03           0xc0


// 0x00004421   P04-P07 function select register
#define EGPIO_P0_47_CFP                 (*(volatile unsigned char*)0x00004421)
    // [1:0]    P04 port extended function
    #define EGPIO_P0_47_CFP_CFP04           0x03

    // [3:2]    P05 port extended function
    #define EGPIO_P0_47_CFP_CFP05           0x0c

    // [5:4]    P06 port extended function
    #define EGPIO_P0_47_CFP_CFP06           0x30

    // [7:6]    P07 port extended function
    #define EGPIO_P0_47_CFP_CFP07           0xc0


// 0x00004422   P10-P13 function select register
#define EGPIO_P1_03_CFP                 (*(volatile unsigned char*)0x00004422)
    // [1:0]    P10 port extended function
    #define EGPIO_P1_03_CFP_CFP10           0x03

    // [3:2]    P11 port extended function
    #define EGPIO_P1_03_CFP_CFP11           0x0c

    // [5:4]    P12 port extended function
    #define EGPIO_P1_03_CFP_CFP12           0x30

    // [7:6]    P13 port extended function
    #define EGPIO_P1_03_CFP_CFP13           0xc0


// 0x00004423   P14-P16 function select register
#define EGPIO_P1_46_CFP                 (*(volatile unsigned char*)0x00004423)
    // [1:0]    P14 port extended function
    #define EGPIO_P1_46_CFP_CFP14           0x03

    // [3:2]    P11 port extended function
    #define EGPIO_P1_46_CFP_CFP15           0x0c

    // [5:4]    P12 port extended function
    #define EGPIO_P1_46_CFP_CFP16           0x30


// 0x00004424   P20-P23 function select register
#define EGPIO_P2_03_CFP                 (*(volatile unsigned char*)0x00004424)
    // [1:0]    P20 port extended function
    #define EGPIO_P2_03_CFP_CFP20           0x03

    // [3:2]    P21 port extended function
    #define EGPIO_P2_03_CFP_CFP21           0x0c

    // [5:4]    P22 port extended function
    #define EGPIO_P2_03_CFP_CFP22           0x30

    // [7:6]    P23 port extended function
    #define EGPIO_P2_03_CFP_CFP23           0xc0


// 0x00004425   P24-P27 function select register
#define EGPIO_P2_47_CFP                 (*(volatile unsigned char*)0x00004425)
    // [1:0]    P24 port extended function
    #define EGPIO_P2_47_CFP_CFP24           0x03

    // [3:2]    P25 port extended function
    #define EGPIO_P2_47_CFP_CFP25           0x0c

    // [5:4]    P26 port extended function
    #define EGPIO_P2_47_CFP_CFP26           0x30

    // [7:6]    P27 port extended function
    #define EGPIO_P2_47_CFP_CFP27           0xc0


// 0x00004426   P30-P33 function select register
#define EGPIO_P3_03_CFP                 (*(volatile unsigned char*)0x00004426)
    // [1:0]    P30 port extended function
    #define EGPIO_P3_03_CFP_CFP30           0x03

    // [3:2]    P31 port extended function
    #define EGPIO_P3_03_CFP_CFP31           0x0c

    // [5:4]    P32 port extended function
    #define EGPIO_P3_03_CFP_CFP32           0x30

    // [7:6]    P33 port extended function
    #define EGPIO_P3_03_CFP_CFP33           0xc0


// 0x00004427   P34-P37 function select register
#define EGPIO_P3_47_CFP                 (*(volatile unsigned char*)0x00004427)
    // [1:0]    P34 port extended function
    #define EGPIO_P3_47_CFP_CFP34           0x03

    // [3:2]    P35 port extended function
    #define EGPIO_P3_47_CFP_CFP35           0x0c

    // [5:4]    P36 port extended function
    #define EGPIO_P3_47_CFP_CFP36           0x30

    // [7:6]    P37 port extended function
    #define EGPIO_P3_47_CFP_CFP37           0xc0


// 0x00004428   P40-P43 function select register
#define EGPIO_P4_03_CFP                 (*(volatile unsigned char*)0x00004428)
    // [1:0]    P40 port extended function
    #define EGPIO_P4_03_CFP_CFP40           0x03

    // [3:2]    P41 port extended function
    #define EGPIO_P4_03_CFP_CFP41           0x0c

    // [5:4]    P42 port extended function
    #define EGPIO_P4_03_CFP_CFP42           0x30

    // [7:6]    P43 port extended function
    #define EGPIO_P4_03_CFP_CFP43           0xc0


// 0x00004429   P44-P45 function select register
#define EGPIO_P4_45_CFP                 (*(volatile unsigned char*)0x00004429)
    // [1:0]    P44 port extended function
    #define EGPIO_P4_45_CFP_CFP44           0x03

    // [3:2]    P45 port extended function
    #define EGPIO_P4_45_CFP_CFP45           0x0c


// 0x0000442a   P50-P53 function select register
#define EGPIO_P5_03_CFP                 (*(volatile unsigned char*)0x0000442a)
    // [1:0]    P50 port extended function
    #define EGPIO_P5_03_CFP_CFP50           0x03

    // [3:2]    P51 port extended function
    #define EGPIO_P5_03_CFP_CFP51           0x0c

    // [5:4]    P52 port extended function
    #define EGPIO_P5_03_CFP_CFP52           0x30

    // [7:6]    P53 port extended function
    #define EGPIO_P5_03_CFP_CFP53           0xc0


// 0x0000442b   P54-P57 function select register
#define EGPIO_P5_47_CFP                 (*(volatile unsigned char*)0x0000442b)
    // [1:0]    P54 port extended function
    #define EGPIO_P5_47_CFP_CFP54           0x03

    // [3:2]    P55 port extended function
    #define EGPIO_P5_47_CFP_CFP55           0x0c

    // [5:4]    P56 port extended function
    #define EGPIO_P5_47_CFP_CFP56           0x30

    // [7:6]    P57 port extended function
    #define EGPIO_P5_47_CFP_CFP57           0xc0


// 0x0000442c   P60-P63 function select register
#define EGPIO_P6_03_CFP                 (*(volatile unsigned char*)0x0000442c)
    // [1:0]    P60 port extended function
    #define EGPIO_P6_03_CFP_CFP60           0x03

    // [3:2]    P61 port extended function
    #define EGPIO_P6_03_CFP_CFP61           0x0c

    // [5:4]    P62 port extended function
    #define EGPIO_P6_03_CFP_CFP62           0x30

    // [7:6]    P63 port extended function
    #define EGPIO_P6_03_CFP_CFP63           0xc0


// 0x0000442d   P64-P67 function select register
#define EGPIO_P6_47_CFP                 (*(volatile unsigned char*)0x0000442d)
    // [1:0]    P64 port extended function
    #define EGPIO_P6_47_CFP_CFP64           0x03

    // [3:2]    P65 port extended function
    #define EGPIO_P6_47_CFP_CFP65           0x0c

    // [5:4]    P66 port extended function
    #define EGPIO_P6_47_CFP_CFP66           0x30

    // [7:6]    P67 port extended function
    #define EGPIO_P6_47_CFP_CFP67           0xc0


// 0x0000442e   P70-P73 function select register
#define EGPIO_P7_03_CFP                 (*(volatile unsigned char*)0x0000442e)
    // [1:0]    P70 port extended function
    #define EGPIO_P7_03_CFP_CFP70           0x03

    // [3:2]    P71 port extended function
    #define EGPIO_P7_03_CFP_CFP71           0x0c

    // [5:4]    P72 port extended function
    #define EGPIO_P7_03_CFP_CFP72           0x30

    // [7:6]    P73 port extended function
    #define EGPIO_P7_03_CFP_CFP73           0xc0


// 0x0000442f   P74-P77 function select register
#define EGPIO_P7_47_CFP                 (*(volatile unsigned char*)0x0000442f)
    // [1:0]    P74 port extended function
    #define EGPIO_P7_47_CFP_CFP74           0x03

    // [3:2]    P75 port extended function
    #define EGPIO_P7_47_CFP_CFP75           0x0c

    // [5:4]    P76 port extended function
    #define EGPIO_P7_47_CFP_CFP76           0x30

    // [7:6]    P77 port extended function
    #define EGPIO_P7_47_CFP_CFP77           0xc0


// 0x00004430   P80-P83 function select register
#define EGPIO_P8_03_CFP                 (*(volatile unsigned char*)0x00004430)
    // [1:0]    P80 port extended function
    #define EGPIO_P8_03_CFP_CFP80           0x03

    // [3:2]    P81 port extended function
    #define EGPIO_P8_03_CFP_CFP81           0x0c

    // [5:4]    P82 port extended function
    #define EGPIO_P8_03_CFP_CFP82           0x30

    // [7:6]    P83 port extended function
    #define EGPIO_P8_03_CFP_CFP83           0xc0


// 0x00004431   P84-P86 function select register
#define EGPIO_P8_46_CFP                 (*(volatile unsigned char*)0x00004431)
    // [1:0]    P84 port extended function
    #define EGPIO_P8_46_CFP_CFP84           0x03

    // [3:2]    P85 port extended function
    #define EGPIO_P8_46_CFP_CFP85           0x0c

    // [5:4]    P86 port extended function
    #define EGPIO_P8_46_CFP_CFP86           0x30


// 0x00004432   P90-P93 function select register
#define EGPIO_P9_03_CFP                 (*(volatile unsigned char*)0x00004432)
    // [1:0]    P90 port extended function
    #define EGPIO_P9_03_CFP_CFP90           0x03

    // [3:2]    P91 port extended function
    #define EGPIO_P9_03_CFP_CFP91           0x0c

    // [5:4]    P92 port extended function
    #define EGPIO_P9_03_CFP_CFP92           0x30

    // [7:6]    P93 port extended function
    #define EGPIO_P9_03_CFP_CFP93           0xc0


// 0x00004433   P94-P97 function select register
#define EGPIO_P9_47_CFP                 (*(volatile unsigned char*)0x00004433)
    // [1:0]    P94 port extended function
    #define EGPIO_P9_47_CFP_CFP94           0x03

    // [3:2]    P95 port extended function
    #define EGPIO_P9_47_CFP_CFP95           0x0c

    // [5:4]    P96 port extended function
    #define EGPIO_P9_47_CFP_CFP96           0x30

    // [7:6]    P97 port extended function
    #define EGPIO_P9_47_CFP_CFP97           0xc0


// 0x00004434   PA0-PA3 function select register
#define EGPIO_PA_03_CFP                 (*(volatile unsigned char*)0x00004434)
    // [1:0]    PA0 port extended function
    #define EGPIO_PA_03_CFP_CFPA0           0x03

    // [3:2]    PA1 port extended function
    #define EGPIO_PA_03_CFP_CFPA1           0x0c

    // [5:4]    PA2 port extended function
    #define EGPIO_PA_03_CFP_CFPA2           0x30

    // [7:6]    PA3 port extended function
    #define EGPIO_PA_03_CFP_CFPA3           0xc0


// 0x00004435   PA4-PA6 function select register
#define EGPIO_PA_46_CFP                 (*(volatile unsigned char*)0x00004435)
    // [1:0]    PA4 port extended function
    #define EGPIO_PA_46_CFP_CFPA4           0x03

    // [3:2]    PA5 port extended function
    #define EGPIO_PA_46_CFP_CFPA5           0x0c

    // [5:4]    PA6 port extended function
    #define EGPIO_PA_46_CFP_CFPA6           0x30


// 0x00004436   PB0-PB3 function select register
#define EGPIO_PB_03_CFP                 (*(volatile unsigned char*)0x00004436)
    // [1:0]    PB0 port extended function
    #define EGPIO_PB_03_CFP_CFPB0           0x03

    // [3:2]    PB1 port extended function
    #define EGPIO_PB_03_CFP_CFPB1           0x0c

    // [5:4]    PB2 port extended function
    #define EGPIO_PB_03_CFP_CFPB2           0x30

    // [7:6]    PB3 port extended function
    #define EGPIO_PB_03_CFP_CFPB3           0xc0


// 0x00004437   PB4-PB7 function select register
#define EGPIO_PB_47_CFP                 (*(volatile unsigned char*)0x00004437)
    // [1:0]    PB4 port extended function
    #define EGPIO_PB_47_CFP_CFPB4           0x03

    // [3:2]    PB5 port extended function
    #define EGPIO_PB_47_CFP_CFPB5           0x0c

    // [5:4]    PB6 port extended function
    #define EGPIO_PB_47_CFP_CFPB6           0x30

    // [7:6]    PB7 port extended function
    #define EGPIO_PB_47_CFP_CFPB7           0xc0


// 0x00004438   PC0-PC3 function select register
#define EGPIO_PC_03_CFP                 (*(volatile unsigned char*)0x00004438)
    // [1:0]    PC0 port extended function
    #define EGPIO_PC_03_CFP_CFPC0           0x03

    // [3:2]    PC1 port extended function
    #define EGPIO_PC_03_CFP_CFPC1           0x0c

    // [5:4]    PC2 port extended function
    #define EGPIO_PC_03_CFP_CFPC2           0x30

    // [7:6]    PC3 port extended function
    #define EGPIO_PC_03_CFP_CFPC3           0xc0


// 0x00004439   PC4-PC7 function select register
#define EGPIO_PC_47_CFP                 (*(volatile unsigned char*)0x00004439)
    // [1:0]    PC4 port extended function
    #define EGPIO_PC_47_CFP_CFPC4           0x03

    // [3:2]    PC5 port extended function
    #define EGPIO_PC_47_CFP_CFPC5           0x0c

    // [5:4]    PC6 port extended function
    #define EGPIO_PC_47_CFP_CFPC6           0x30

    // [7:6]    PC7 port extended function
    #define EGPIO_PC_47_CFP_CFPC7           0xc0


// 0x00004440   Port input interrupt 0 Select registar
#define EGPIO_PINTSEL_SPT0              (*(volatile unsigned char*)0x00004440)
    // [7:4]    Select port input interrupt 0
    #define EGPIO_PINTSEL_SPT0_SPPT         0xf0


// 0x00004441   Port input interrupt 1 Select registar
#define EGPIO_PINTSEL_SPT1              (*(volatile unsigned char*)0x00004441)
    // [7:4]    Select port input interrupt 1
    #define EGPIO_PINTSEL_SPT1_SPPT         0xf0


// 0x00004442   Port input interrupt 2 Select registar
#define EGPIO_PINTSEL_SPT2              (*(volatile unsigned char*)0x00004442)
    // [7:4]    Select port input interrupt 2
    #define EGPIO_PINTSEL_SPT2_SPPT         0xf0


// 0x00004443   Port input interrupt 3 Select registar
#define EGPIO_PINTSEL_SPT3              (*(volatile unsigned char*)0x00004443)
    // [7:4]    Select port input interrupt 3
    #define EGPIO_PINTSEL_SPT3_SPPT         0xf0


// 0x00004444   Port input interrupt 4 Select registar
#define EGPIO_PINTSEL_SPT4              (*(volatile unsigned char*)0x00004444)
    // [7:4]    Select port input interrupt 4
    #define EGPIO_PINTSEL_SPT4_SPPT         0xf0


// 0x00004445   Port input interrupt 5 Select registar
#define EGPIO_PINTSEL_SPT5              (*(volatile unsigned char*)0x00004445)
    // [7:4]    Select port input interrupt 5
    #define EGPIO_PINTSEL_SPT5_SPPT         0xf0


// 0x00004446   Port input interrupt 6 Select registar
#define EGPIO_PINTSEL_SPT6              (*(volatile unsigned char*)0x00004446)
    // [7:4]    Select port input interrupt 6
    #define EGPIO_PINTSEL_SPT6_SPPT         0xf0


// 0x00004447   Port input interrupt 7 Select registar
#define EGPIO_PINTSEL_SPT7              (*(volatile unsigned char*)0x00004447)
    // [7:4]    Select port input interrupt 7
    #define EGPIO_PINTSEL_SPT7_SPPT         0xf0


/*****************************************************************************
    USB     (0x00004500)    USB Function Controller
*****************************************************************************/

// 0x00004500   Main interrupt status
#define USB_MainIntStat                 (*(volatile unsigned char*)0x00004500)
    // [0]
    #define USB_MainIntStat_RcvEP0SETUP     0x01

    // [1]
    #define USB_MainIntStat_EP0IntStat      0x02

    // [4]
    #define USB_MainIntStat_FIFOIntStat     0x10

    // [5]
    #define USB_MainIntStat_DMAIntStat      0x20

    // [6]
    #define USB_MainIntStat_EPrIntStat      0x40

    // [7]
    #define USB_MainIntStat_SIEIntStat      0x80


// 0x00004501   SIE interrupt status
#define USB_SIEIntStat                  (*(volatile unsigned char*)0x00004501)
    // [0]
    #define USB_SIEIntStat_SetAddressCmp    0x01

    // [2]
    #define USB_SIEIntStat_DetectJ          0x04

    // [3]
    #define USB_SIEIntStat_RcvSOF           0x08

    // [4]
    #define USB_SIEIntStat_DetectSuspend    0x10

    // [5]
    #define USB_SIEIntStat_DetectReset      0x20

    // [6]
    #define USB_SIEIntStat_NonJ             0x40

    // [7]
    #define USB_SIEIntStat_VBUSChanged      0x80


// 0x00004502   EPr interrupt status
#define USB_EPrIntStat                  (*(volatile unsigned char*)0x00004502)
    // [0]
    #define USB_EPrIntStat_EPaIntStat       0x01

    // [1]
    #define USB_EPrIntStat_EPbIntStat       0x02

    // [2]
    #define USB_EPrIntStat_EPcIntStat       0x04

    // [3]
    #define USB_EPrIntStat_EPdIntStat       0x08


// 0x00004503   DMA interrupt status
#define USB_DMAIntStat                  (*(volatile unsigned char*)0x00004503)
    // [0]
    #define USB_DMAIntStat_DMACmp           0x01

    // [1]
    #define USB_DMAIntStat_DMACountUp       0x02


// 0x00004504   FIFO interrupt status
#define USB_FIFOIntStat                 (*(volatile unsigned char*)0x00004504)
    // [0]
    #define USB_FIFOIntStat_FIFOOUTCmp      0x01

    // [1]
    #define USB_FIFOIntStat_FIFOINCmp       0x02

    // [7]
    #define USB_FIFOIntStat_DescriptorCmp   0x80


// 0x00004507   EP0 interrupt status
#define USB_EP0IntStat                  (*(volatile unsigned char*)0x00004507)
    // [0]
    #define USB_EP0IntStat_OUTTranErr       0x01

    // [1]
    #define USB_EP0IntStat_INTranErr        0x02

    // [2]
    #define USB_EP0IntStat_OUTTranNAK       0x04

    // [3]
    #define USB_EP0IntStat_INTranNAK        0x08

    // [4]
    #define USB_EP0IntStat_OUTTranACK       0x10

    // [5]
    #define USB_EP0IntStat_INTranACK        0x20


// 0x00004508   EPa interrupt status
#define USB_EPaIntStat                  (*(volatile unsigned char*)0x00004508)
    // [0]
    #define USB_EPaIntStat_OUTTranErr       0x01

    // [1]
    #define USB_EPaIntStat_INTranErr        0x02

    // [2]
    #define USB_EPaIntStat_OUTTranNAK       0x04

    // [3]
    #define USB_EPaIntStat_INTranNAK        0x08

    // [4]
    #define USB_EPaIntStat_OUTTranACK       0x10

    // [5]
    #define USB_EPaIntStat_INTranACK        0x20

    // [6]
    #define USB_EPaIntStat_OUTShortACK      0x40


// 0x00004509   EPb interrupt status
#define USB_EPbIntStat                  (*(volatile unsigned char*)0x00004509)
    // [0]
    #define USB_EPbIntStat_OUTTranErr       0x01

    // [1]
    #define USB_EPbIntStat_INTranErr        0x02

    // [2]
    #define USB_EPbIntStat_OUTTranNAK       0x04

    // [3]
    #define USB_EPbIntStat_INTranNAK        0x08

    // [4]
    #define USB_EPbIntStat_OUTTranACK       0x10

    // [5]
    #define USB_EPbIntStat_INTranACK        0x20

    // [6]
    #define USB_EPbIntStat_OUTShortACK      0x40


// 0x0000450a   EPc interrupt status
#define USB_EPcIntStat                  (*(volatile unsigned char*)0x0000450a)
    // [0]
    #define USB_EPcIntStat_OUTTranErr       0x01

    // [1]
    #define USB_EPcIntStat_INTranErr        0x02

    // [2]
    #define USB_EPcIntStat_OUTTranNAK       0x04

    // [3]
    #define USB_EPcIntStat_INTranNAK        0x08

    // [4]
    #define USB_EPcIntStat_OUTTranACK       0x10

    // [5]
    #define USB_EPcIntStat_INTranACK        0x20

    // [6]
    #define USB_EPcIntStat_OUTShortACK      0x40


// 0x0000450b   EPd interrupt status
#define USB_EPdIntStat                  (*(volatile unsigned char*)0x0000450b)
    // [0]
    #define USB_EPdIntStat_OUTTranErr       0x01

    // [1]
    #define USB_EPdIntStat_INTranErr        0x02

    // [2]
    #define USB_EPdIntStat_OUTTranNAK       0x04

    // [3]
    #define USB_EPdIntStat_INTranNAK        0x08

    // [4]
    #define USB_EPdIntStat_OUTTranACK       0x10

    // [5]
    #define USB_EPdIntStat_INTranACK        0x20

    // [6]
    #define USB_EPdIntStat_OUTShortACK      0x40


// 0x00004510   Main interrupt enable
#define USB_MainIntEnb                  (*(volatile unsigned char*)0x00004510)
    // [0]
    #define USB_MainIntEnb_EnRcvEP0SETUP    0x01

    // [1]
    #define USB_MainIntEnb_EnEP0IntStat     0x02

    // [4]
    #define USB_MainIntEnb_EnFIFOIntStat    0x10

    // [5]
    #define USB_MainIntEnb_EnDMAIntStat     0x20

    // [6]
    #define USB_MainIntEnb_EnEPrIntStat     0x40

    // [7]
    #define USB_MainIntEnb_EnSIEIntStat     0x80


// 0x00004511   SIE interrupt enable
#define USB_SIEIntEnb                   (*(volatile unsigned char*)0x00004511)
    // [0]
    #define USB_SIEIntEnb_EnSetAddressCmp   0x01

    // [2]
    #define USB_SIEIntEnb_EnDetectJ         0x04

    // [3]
    #define USB_SIEIntEnb_EnRcvSOF          0x08

    // [4]
    #define USB_SIEIntEnb_EnDetectSuspend   0x10

    // [5]
    #define USB_SIEIntEnb_EnDetectReset     0x20

    // [6]
    #define USB_SIEIntEnb_EnNonJ            0x40

    // [7]
    #define USB_SIEIntEnb_EnVBUSChanged     0x80


// 0x00004512   EPr interrupt enable
#define USB_EPrIntEnb                   (*(volatile unsigned char*)0x00004512)
    // [0]
    #define USB_EPrIntEnb_EnEPaIntStat      0x01

    // [1]
    #define USB_EPrIntEnb_EnEPbIntStat      0x02

    // [2]
    #define USB_EPrIntEnb_EnEPcIntStat      0x04

    // [3]
    #define USB_EPrIntEnb_EnEPdIntStat      0x08


// 0x00004513   DMA interrupt enable
#define USB_DMAIntEnb                   (*(volatile unsigned char*)0x00004513)
    // [0]
    #define USB_DMAIntEnb_EnDMACmp          0x01

    // [1]
    #define USB_DMAIntEnb_EnDMACountUp      0x02


// 0x00004514   FIFO interrupt enable
#define USB_FIFOIntEnb                  (*(volatile unsigned char*)0x00004514)
    // [0]
    #define USB_FIFOIntEnb_EnFIFOOUTCmp     0x01

    // [1]
    #define USB_FIFOIntEnb_EnFIFOINCmp      0x02

    // [7]
    #define USB_FIFOIntEnb_EnDescriptorCmp  0x80


// 0x00004517   EP0 interrupt enable
#define USB_EP0IntEnb                   (*(volatile unsigned char*)0x00004517)
    // [0]
    #define USB_EP0IntEnb_EnOUTTranErr      0x01

    // [1]
    #define USB_EP0IntEnb_EnINTranErr       0x02

    // [2]
    #define USB_EP0IntEnb_EnOUTTranNAK      0x04

    // [3]
    #define USB_EP0IntEnb_EnINTranNAK       0x08

    // [4]
    #define USB_EP0IntEnb_EnOUTTranACK      0x10

    // [5]
    #define USB_EP0IntEnb_EnINTranACK       0x20


// 0x00004518   EPa interrupt enable
#define USB_EPaIntEnb                   (*(volatile unsigned char*)0x00004518)
    // [0]
    #define USB_EPaIntEnb_EnOUTTranErr      0x01

    // [1]
    #define USB_EPaIntEnb_EnINTranErr       0x02

    // [2]
    #define USB_EPaIntEnb_EnOUTTranNAK      0x04

    // [3]
    #define USB_EPaIntEnb_EnINTranNAK       0x08

    // [4]
    #define USB_EPaIntEnb_EnOUTTranACK      0x10

    // [5]
    #define USB_EPaIntEnb_EnINTranACK       0x20

    // [6]
    #define USB_EPaIntEnb_EnOUTShortACK     0x40


// 0x00004519   EPb interrupt enable
#define USB_EPbIntEnb                   (*(volatile unsigned char*)0x00004519)
    // [0]
    #define USB_EPbIntEnb_EnOUTTranErr      0x01

    // [1]
    #define USB_EPbIntEnb_EnINTranErr       0x02

    // [2]
    #define USB_EPbIntEnb_EnOUTTranNAK      0x04

    // [3]
    #define USB_EPbIntEnb_EnINTranNAK       0x08

    // [4]
    #define USB_EPbIntEnb_EnOUTTranACK      0x10

    // [5]
    #define USB_EPbIntEnb_EnINTranACK       0x20

    // [6]
    #define USB_EPbIntEnb_EnOUTShortACK     0x40


// 0x0000451a   EPc interrupt enable
#define USB_EPcIntEnb                   (*(volatile unsigned char*)0x0000451a)
    // [0]
    #define USB_EPcIntEnb_EnOUTTranErr      0x01

    // [1]
    #define USB_EPcIntEnb_EnINTranErr       0x02

    // [2]
    #define USB_EPcIntEnb_EnOUTTranNAK      0x04

    // [3]
    #define USB_EPcIntEnb_EnINTranNAK       0x08

    // [4]
    #define USB_EPcIntEnb_EnOUTTranACK      0x10

    // [5]
    #define USB_EPcIntEnb_EnINTranACK       0x20

    // [6]
    #define USB_EPcIntEnb_EnOUTShortACK     0x40


// 0x0000451b   EPd interrupt enable
#define USB_EPdIntEnb                   (*(volatile unsigned char*)0x0000451b)
    // [0]
    #define USB_EPdIntEnb_EnOUTTranErr      0x01

    // [1]
    #define USB_EPdIntEnb_EnINTranErr       0x02

    // [2]
    #define USB_EPdIntEnb_EnOUTTranNAK      0x04

    // [3]
    #define USB_EPdIntEnb_EnINTranNAK       0x08

    // [4]
    #define USB_EPdIntEnb_EnOUTTranACK      0x10

    // [5]
    #define USB_EPdIntEnb_EnINTranACK       0x20

    // [6]
    #define USB_EPdIntEnb_EnOUTShortACK     0x40


// 0x00004520   Revision number
#define USB_RevisionNum                 (*(volatile unsigned char*)0x00004520)
    // [7:0]
    #define USB_RevisionNum_RevisionNum     0xff


// 0x00004521   USB control register
#define USB_USBControl                  (*(volatile unsigned char*)0x00004521)
    // [0]
    #define USB_USBControl_ActiveUSB        0x01

    // [3]
    #define USB_USBControl_SendWakeup       0x08

    // [4]
    #define USB_USBControl_StartDetectJ     0x10

    // [5]
    #define USB_USBControl_InSUSPEND        0x20

    // [6]
    #define USB_USBControl_EnAutoNego       0x40

    // [7]
    #define USB_USBControl_DisBusDetect     0x80


// 0x00004522   USB status register
#define USB_USBStatus                   (*(volatile unsigned char*)0x00004522)
    // [1:0]
    #define USB_USBStatus_LineState         0x03

    // [6]
    #define USB_USBStatus_FS                0x40

    // [7]
    #define USB_USBStatus_VBUS              0x80


// 0x00004523   Xcvr control register
#define USB_XcvrControl                 (*(volatile unsigned char*)0x00004523)
    // [1:0]
    #define USB_XcvrControl_OpMode          0x03

    // [7]
    #define USB_XcvrControl_RpuEnb          0x80


// 0x00004524   USB test
#define USB_USBTest                     (*(volatile unsigned char*)0x00004524)
    // [0]
    #define USB_USBTest_TestPacket          0x01

    // [1]
    #define USB_USBTest_TestK               0x02

    // [2]
    #define USB_USBTest_TestJ               0x04

    // [3]
    #define USB_USBTest_TestSE0NAK          0x08

    // [7]
    #define USB_USBTest_EnUSBTest           0x80


// 0x00004525   Endpoint control
#define USB_EPnControl                  (*(volatile unsigned char*)0x00004525)
    // [0]
    #define USB_EPnControl_EP0FIFOClr       0x01

    // [5]
    #define USB_EPnControl_AllFIFOClr       0x20

    // [6]
    #define USB_EPnControl_EPrForceSTALL    0x40

    // [7]
    #define USB_EPnControl_AllForceNAK      0x80


// 0x00004526   EPr FIFO clear
#define USB_EPrFIFOClr                  (*(volatile unsigned char*)0x00004526)
    // [0]
    #define USB_EPrFIFOClr_EPaFIFOClr       0x01

    // [1]
    #define USB_EPrFIFOClr_EPbFIFOClr       0x02

    // [2]
    #define USB_EPrFIFOClr_EPcFIFOClr       0x04

    // [3]
    #define USB_EPrFIFOClr_EPdFIFOClr       0x08


// 0x0000452e   Frame number high
#define USB_FrameNumberH                (*(volatile unsigned char*)0x0000452e)
    // [2:0]
    #define USB_FrameNumberH_FrameNumber    0x07

    // [7]
    #define USB_FrameNumberH_FnInvalid      0x80


// 0x0000452f   Frame number low
#define USB_FrameNumberL                (*(volatile unsigned char*)0x0000452f)
    // [7:0]
    #define USB_FrameNumberL_FrameNumber    0xff


// 0x00004530   EP0 set-up 0
#define USB_EP0Setup0                   (*(volatile unsigned char*)0x00004530)
    // [7:0]
    #define USB_EP0Setup0_EP0Setup0         0xff


// 0x00004531   EP0 set-up 1
#define USB_EP0Setup1                   (*(volatile unsigned char*)0x00004531)
    // [7:0]
    #define USB_EP0Setup1_EP0Setup1         0xff


// 0x00004532   EP0 set-up 2
#define USB_EP0Setup2                   (*(volatile unsigned char*)0x00004532)
    // [7:0]
    #define USB_EP0Setup2_EP0Setup2         0xff


// 0x00004533   EP0 set-up 3
#define USB_EP0Setup3                   (*(volatile unsigned char*)0x00004533)
    // [7:0]
    #define USB_EP0Setup3_EP0Setup3         0xff


// 0x00004534   EP0 set-up 4
#define USB_EP0Setup4                   (*(volatile unsigned char*)0x00004534)
    // [7:0]
    #define USB_EP0Setup4_EP0Setup4         0xff


// 0x00004535   EP0 set-up 5
#define USB_EP0Setup5                   (*(volatile unsigned char*)0x00004535)
    // [7:0]
    #define USB_EP0Setup5_EP0Setup5         0xff


// 0x00004536   EP0 set-up 6
#define USB_EP0Setup6                   (*(volatile unsigned char*)0x00004536)
    // [7:0]
    #define USB_EP0Setup6_EP0Setup6         0xff


// 0x00004537   EP0 set-up 7
#define USB_EP0Setup7                   (*(volatile unsigned char*)0x00004537)
    // [7:0]
    #define USB_EP0Setup7_EP0Setup7         0xff


// 0x00004538   USB address
#define USB_USBAddress                  (*(volatile unsigned char*)0x00004538)
    // [6:0]
    #define USB_USBAddress_USBAddress       0x7f

    // [7]
    #define USB_USBAddress_AutoSetAddress   0x80


// 0x00004539   EP0 control
#define USB_EP0Control                  (*(volatile unsigned char*)0x00004539)
    // [0]
    #define USB_EP0Control_ReplyDescriptor  0x01

    // [7]
    #define USB_EP0Control_INxOUT           0x80


// 0x0000453a   EP0 control IN
#define USB_EP0ControlIN                (*(volatile unsigned char*)0x0000453a)
    // [0]
    #define USB_EP0ControlIN_ForceSTALL     0x01

    // [1]
    #define USB_EP0ControlIN_ForceNAK       0x02

    // [2]
    #define USB_EP0ControlIN_ToggleClr      0x04

    // [3]
    #define USB_EP0ControlIN_ToggleSet      0x08

    // [4]
    #define USB_EP0ControlIN_ToggleStat     0x10

    // [6]
    #define USB_EP0ControlIN_EnShortPkt     0x40


// 0x0000453b   EP0 control OUT
#define USB_EP0ControlOUT               (*(volatile unsigned char*)0x0000453b)
    // [0]
    #define USB_EP0ControlOUT_ForceSTALL    0x01

    // [1]
    #define USB_EP0ControlOUT_ForceNAK      0x02

    // [2]
    #define USB_EP0ControlOUT_ToggleClr     0x04

    // [3]
    #define USB_EP0ControlOUT_ToggleSet     0x08

    // [4]
    #define USB_EP0ControlOUT_ToggleStat    0x10

    // [7]
    #define USB_EP0ControlOUT_AutoForceNAK  0x80


// 0x0000453f   EP0 max packet size
#define USB_EP0MaxSize                  (*(volatile unsigned char*)0x0000453f)
    // [6:3]
    #define USB_EP0MaxSize_EP0MaxSize       0x78


// 0x00004540   EPa control
#define USB_EPaControl                  (*(volatile unsigned char*)0x00004540)
    // [0]
    #define USB_EPaControl_ForceSTALL       0x01

    // [1]
    #define USB_EPaControl_ForceNAK         0x02

    // [2]
    #define USB_EPaControl_ToggleClr        0x04

    // [3]
    #define USB_EPaControl_ToggleSet        0x08

    // [4]
    #define USB_EPaControl_ToggleStat       0x10

    // [5]
    #define USB_EPaControl_DisAFNAKShort    0x20

    // [6]
    #define USB_EPaControl_EnShortPkt       0x40

    // [7]
    #define USB_EPaControl_AutoForceNAK     0x80


// 0x00004541   EPb control
#define USB_EPbControl                  (*(volatile unsigned char*)0x00004541)
    // [0]
    #define USB_EPbControl_ForceSTALL       0x01

    // [1]
    #define USB_EPbControl_ForceNAK         0x02

    // [2]
    #define USB_EPbControl_ToggleClr        0x04

    // [3]
    #define USB_EPbControl_ToggleSet        0x08

    // [4]
    #define USB_EPbControl_ToggleStat       0x10

    // [5]
    #define USB_EPbControl_DisAFNAKShort    0x20

    // [6]
    #define USB_EPbControl_EnShortPkt       0x40

    // [7]
    #define USB_EPbControl_AutoForceNAK     0x80


// 0x00004542   EPc control
#define USB_EPcControl                  (*(volatile unsigned char*)0x00004542)
    // [0]
    #define USB_EPcControl_ForceSTALL       0x01

    // [1]
    #define USB_EPcControl_ForceNAK         0x02

    // [2]
    #define USB_EPcControl_ToggleClr        0x04

    // [3]
    #define USB_EPcControl_ToggleSet        0x08

    // [4]
    #define USB_EPcControl_ToggleStat       0x10

    // [5]
    #define USB_EPcControl_DisAFNAKShort    0x20

    // [6]
    #define USB_EPcControl_EnShortPkt       0x40

    // [7]
    #define USB_EPcControl_AutoForceNAK     0x80


// 0x00004543   EPd control
#define USB_EPdControl                  (*(volatile unsigned char*)0x00004543)
    // [0]
    #define USB_EPdControl_ForceSTALL       0x01

    // [1]
    #define USB_EPdControl_ForceNAK         0x02

    // [2]
    #define USB_EPdControl_ToggleClr        0x04

    // [3]
    #define USB_EPdControl_ToggleSet        0x08

    // [4]
    #define USB_EPdControl_ToggleStat       0x10

    // [5]
    #define USB_EPdControl_DisAFNAKShort    0x20

    // [6]
    #define USB_EPdControl_EnShortPkt       0x40

    // [7]
    #define USB_EPdControl_AutoForceNAK     0x80


// 0x00004550   EPa max packet size high
#define USB_EPaMaxSizeH                 (*(volatile unsigned char*)0x00004550)
    // [1:0]
    #define USB_EPaMaxSizeH_EPaMaxSize      0x03


// 0x00004551   EPa max packet size low
#define USB_EPaMaxSizeL                 (*(volatile unsigned char*)0x00004551)
    // [7:0]
    #define USB_EPaMaxSizeL_EPaMaxSize      0xff


// 0x00004552   EPa configuration 0
#define USB_EPaConfig0                  (*(volatile unsigned char*)0x00004552)
    // [3:0]
    #define USB_EPaConfig0_EndPointNumber   0x0f

    // [5]
    #define USB_EPaConfig0_EnEndPoint       0x20

    // [6]
    #define USB_EPaConfig0_ToggleMode       0x40

    // [7]
    #define USB_EPaConfig0_INxOUT           0x80


// 0x00004553   EPa configuration 1
#define USB_EPaConfig1                  (*(volatile unsigned char*)0x00004553)
    // [6]
    #define USB_EPaConfig1_ISOCRCmode       0x40

    // [7]
    #define USB_EPaConfig1_ISO              0x80


// 0x00004554   EPb max packet size high
#define USB_EPbMaxSizeH                 (*(volatile unsigned char*)0x00004554)
    // [1:0]
    #define USB_EPbMaxSizeH_EPbMaxSize      0x03


// 0x00004555   EPb max packet size low
#define USB_EPbMaxSizeL                 (*(volatile unsigned char*)0x00004555)
    // [7:0]
    #define USB_EPbMaxSizeL_EPbMaxSize      0xff


// 0x00004556   EPb configuration 0
#define USB_EPbConfig0                  (*(volatile unsigned char*)0x00004556)
    // [3:0]
    #define USB_EPbConfig0_EndPointNumber   0x0f

    // [5]
    #define USB_EPbConfig0_EnEndPoint       0x20

    // [6]
    #define USB_EPbConfig0_ToggleMode       0x40

    // [7]
    #define USB_EPbConfig0_INxOUT           0x80


// 0x00004557   EPb configuration 1
#define USB_EPbConfig1                  (*(volatile unsigned char*)0x00004557)
    // [6]
    #define USB_EPbConfig1_ISOCRCmode       0x40

    // [7]
    #define USB_EPbConfig1_ISO              0x80


// 0x00004558   EPc max packet size high
#define USB_EPcMaxSizeH                 (*(volatile unsigned char*)0x00004558)
    // [1:0]
    #define USB_EPcMaxSizeH_EPcMaxSize      0x03


// 0x00004559   EPc max packet size low
#define USB_EPcMaxSizeL                 (*(volatile unsigned char*)0x00004559)
    // [7:0]
    #define USB_EPcMaxSizeL_EPcMaxSize      0xff


// 0x0000455a   EPc configuration 0
#define USB_EPcConfig0                  (*(volatile unsigned char*)0x0000455a)
    // [3:0]
    #define USB_EPcConfig0_EndPointNumber   0x0f

    // [5]
    #define USB_EPcConfig0_EnEndPoint       0x20

    // [6]
    #define USB_EPcConfig0_ToggleMode       0x40

    // [7]
    #define USB_EPcConfig0_INxOUT           0x80


// 0x0000455b   EPc configuration 1
#define USB_EPcConfig1                  (*(volatile unsigned char*)0x0000455b)
    // [6]
    #define USB_EPcConfig1_ISOCRCmode       0x40

    // [7]
    #define USB_EPcConfig1_ISO              0x80


// 0x0000455c   EPd max packet size high
#define USB_EPdMaxSizeH                 (*(volatile unsigned char*)0x0000455c)
    // [1:0]
    #define USB_EPdMaxSizeH_EPdMaxSize      0x03


// 0x0000455d   EPd max packet size low
#define USB_EPdMaxSizeL                 (*(volatile unsigned char*)0x0000455d)
    // [7:0]
    #define USB_EPdMaxSizeL_EPdMaxSize      0xff


// 0x0000455e   EPd configuration 0
#define USB_EPdConfig0                  (*(volatile unsigned char*)0x0000455e)
    // [3:0]
    #define USB_EPdConfig0_EndPointNumber   0x0f

    // [5]
    #define USB_EPdConfig0_EnEndPoint       0x20

    // [6]
    #define USB_EPdConfig0_ToggleMode       0x40

    // [7]
    #define USB_EPdConfig0_INxOUT           0x80


// 0x0000455f   EPa configuration 1
#define USB_EPdConfig1                  (*(volatile unsigned char*)0x0000455f)
    // [6]
    #define USB_EPdConfig1_ISOCRCmode       0x40

    // [7]
    #define USB_EPdConfig1_ISO              0x80


// 0x00004570   EPa FIFO start address high
#define USB_EPaStartAdrsH               (*(volatile unsigned char*)0x00004570)
    // [3:0]
    #define USB_EPaStartAdrsH_EPaStartAdrs  0x0f


// 0x00004571   EPa FIFO start address low
#define USB_EPaStartAdrsL               (*(volatile unsigned char*)0x00004571)
    // [7:2]
    #define USB_EPaStartAdrsL_EPaStartAdrs  0xfc


// 0x00004572   EPb FIFO start address high
#define USB_EPbStartAdrsH               (*(volatile unsigned char*)0x00004572)
    // [3:0]
    #define USB_EPbStartAdrsH_EPbStartAdrs  0x0f


// 0x00004573   EPb FIFO start address low
#define USB_EPbStartAdrsL               (*(volatile unsigned char*)0x00004573)
    // [7:2]
    #define USB_EPbStartAdrsL_EPbStartAdrs  0xfc


// 0x00004574   EPc FIFO start address high
#define USB_EPcStartAdrsH               (*(volatile unsigned char*)0x00004574)
    // [3:0]
    #define USB_EPcStartAdrsH_EPcStartAdrs  0x0f


// 0x00004575   EPc FIFO start address low
#define USB_EPcStartAdrsL               (*(volatile unsigned char*)0x00004575)
    // [7:2]
    #define USB_EPcStartAdrsL_EPcStartAdrs  0xfc


// 0x00004576   EPd FIFO start address high
#define USB_EPdStartAdrsH               (*(volatile unsigned char*)0x00004576)
    // [3:0]
    #define USB_EPdStartAdrsH_EPdStartAdrs  0x0f


// 0x00004577   EPd FIFO start address low
#define USB_EPdStartAdrsL               (*(volatile unsigned char*)0x00004577)
    // [7:2]
    #define USB_EPdStartAdrsL_EPdStartAdrs  0xfc


// 0x00004580   CPU join FIFO read
#define USB_CPUJoinRd                   (*(volatile unsigned char*)0x00004580)
    // [0]
    #define USB_CPUJoinRd_JoinEPaRd         0x01

    // [1]
    #define USB_CPUJoinRd_JoinEPbRd         0x02

    // [2]
    #define USB_CPUJoinRd_JoinEPcRd         0x04

    // [3]
    #define USB_CPUJoinRd_JoinEPdRd         0x08


// 0x00004581   CPU join FIFO write
#define USB_CPUJoinWr                   (*(volatile unsigned char*)0x00004581)
    // [0]
    #define USB_CPUJoinWr_JoinEPaWr         0x01

    // [1]
    #define USB_CPUJoinWr_JoinEPbWr         0x02

    // [2]
    #define USB_CPUJoinWr_JoinEPcWr         0x04

    // [3]
    #define USB_CPUJoinWr_JoinEPdWr         0x08


// 0x00004582   Enable EPn FIFO access
#define USB_EnEPnFIFOAccess             (*(volatile unsigned char*)0x00004582)
    // [0]
    #define USB_EnEPnFIFOAccess_EnEPnFIFORd  0x01

    // [1]
    #define USB_EnEPnFIFOAccess_EnEPnFIFOWr  0x02


// 0x00004583   EPn FIFO for CPU
#define USB_EPnFIFOforCPU               (*(volatile unsigned char*)0x00004583)
    // [7:0]
    #define USB_EPnFIFOforCPU_EPnFIFOData   0xff


// 0x00004584   EPn FIFO read remain high
#define USB_EPnRdRemainH                (*(volatile unsigned char*)0x00004584)
    // [3:0]
    #define USB_EPnRdRemainH_EPnRdRemain    0x0f


// 0x00004585   EPn FIFO read remain low
#define USB_EPnRdRemainL                (*(volatile unsigned char*)0x00004585)
    // [7:0]
    #define USB_EPnRdRemainL_EPnRdRemain    0xff


// 0x00004586   EPn FIFO write remain high
#define USB_EPnWrRemainH                (*(volatile unsigned char*)0x00004586)
    // [3:0]
    #define USB_EPnWrRemainH_EPnWrRemain    0x0f


// 0x00004587   EPn FIFO write remain low
#define USB_EPnWrRemainL                (*(volatile unsigned char*)0x00004587)
    // [7:0]
    #define USB_EPnWrRemainL_EPnWrRemain    0xff


// 0x00004588   Descriptor address high
#define USB_DescAdrsH                   (*(volatile unsigned char*)0x00004588)
    // [3:0]
    #define USB_DescAdrsH_DescAdrs          0x0f


// 0x00004589   Descriptor address low
#define USB_DescAdrsL                   (*(volatile unsigned char*)0x00004589)
    // [7:0]
    #define USB_DescAdrsL_DescAdrs          0xff


// 0x0000458a   Descriptor size high
#define USB_DescSizeH                   (*(volatile unsigned char*)0x0000458a)
    // [1:0]
    #define USB_DescSizeH_DescSize          0x03


// 0x0000458b   Descriptor size low
#define USB_DescSizeL                   (*(volatile unsigned char*)0x0000458b)
    // [7:0]
    #define USB_DescSizeL_DescSize          0xff


// 0x0000458f   Descriptor door
#define USB_DescDoor                    (*(volatile unsigned char*)0x0000458f)
    // [7:0]
    #define USB_DescDoor_DescMode           0xff


// 0x00004590   DMA FIFO control
#define USB_DMAFIFOControl              (*(volatile unsigned char*)0x00004590)
    // [6]
    #define USB_DMAFIFOControl_AutoEnShort  0x40

    // [7]
    #define USB_DMAFIFOControl_FIFORunning  0x80


// 0x00004591   DMA join FIFO
#define USB_DMAJoin                     (*(volatile unsigned char*)0x00004591)
    // [0]
    #define USB_DMAJoin_JoinEPaDMA          0x01

    // [1]
    #define USB_DMAJoin_JoinEPbDMA          0x02

    // [2]
    #define USB_DMAJoin_JoinEPcDMA          0x04

    // [3]
    #define USB_DMAJoin_JoinEPdDMA          0x08


// 0x00004592   DMA control
#define USB_DMAControl                  (*(volatile unsigned char*)0x00004592)
    // [0]
    #define USB_DMAControl_DMAGo            0x01

    // [1]
    #define USB_DMAControl_DMAStop          0x02

    // [3]
    #define USB_DMAControl_CounterClr       0x08

    // [5]
    #define USB_DMAControl_PDACK            0x20

    // [6]
    #define USB_DMAControl_PDREQ            0x40

    // [7]
    #define USB_DMAControl_DMARunning       0x80


// 0x00004594   DMA configuration 0
#define USB_DMAConfig0                  (*(volatile unsigned char*)0x00004594)
    // [1]
    #define USB_DMAConfig0_PDRDWRLevel      0x02

    // [2]
    #define USB_DMAConfig0_PDACKLevel       0x04

    // [3]
    #define USB_DMAConfig0_PDREQLevel       0x08

    // [7]
    #define USB_DMAConfig0_ActivePort       0x80


// 0x00004595   DMA configuration 1
#define USB_DMAConfig1                  (*(volatile unsigned char*)0x00004595)
    // [0]
    #define USB_DMAConfig1_CountMode        0x01

    // [3]
    #define USB_DMAConfig1_SingleWord       0x08

    // [7]
    #define USB_DMAConfig1_RcvLimitMode     0x80


// 0x00004597   DMA latency
#define USB_DMALatency                  (*(volatile unsigned char*)0x00004597)
    // [3:0]
    #define USB_DMALatency_DMALatency       0x0f


// 0x00004598   DMA FIFO remain high
#define USB_DMARemainH                  (*(volatile unsigned char*)0x00004598)
    // [3:0]
    #define USB_DMARemainH_DMARemain        0x0f


// 0x00004599   DMA FIFO remain low
#define USB_DMARemainL                  (*(volatile unsigned char*)0x00004599)
    // [7:0]
    #define USB_DMARemainL_DMARemain        0xff


// 0x0000459c   DMA transfer byte counter high/high
#define USB_DMACountHH                  (*(volatile unsigned char*)0x0000459c)
    // [7:0]
    #define USB_DMACountHH_DMACount         0xff


// 0x0000459d   DMA transfer byte counter high/low
#define USB_DMACountHL                  (*(volatile unsigned char*)0x0000459d)
    // [7:0]
    #define USB_DMACountHL_DMACount         0xff


// 0x0000459e   DMA transfer byte counter low/high
#define USB_DMACountLH                  (*(volatile unsigned char*)0x0000459e)
    // [7:0]
    #define USB_DMACountLH_DMACount         0xff


// 0x0000459f   DMA transfer byte counter low/low
#define USB_DMACountLL                  (*(volatile unsigned char*)0x0000459f)
    // [7:0]
    #define USB_DMACountLL_DMACount         0xff


/*****************************************************************************
    RTC     (0x00004600)    RTC Controller
*****************************************************************************/

// 0x00004600   RTC interrupt status register
#define RTC_INTSTAT                     (*(volatile unsigned char*)0x00004600)
    // [0]      Interrupt status
    #define RTC_INTSTAT_RTCIRQ              0x01


// 0x00004601   RTC interrupt mode register
#define RTC_INTMODE                     (*(volatile unsigned char*)0x00004601)
    // [0]      RTC interupt enable
    #define RTC_INTMODE_RTCIEN              0x01

    // [1]      RTC interrupt mode select
    #define RTC_INTMODE_RTCIMD              0x02

    // [3:2]    RTC interrupt cycle setup
    #define RTC_INTMODE_RTCT                0x0c


// 0x00004602   RTC control register
#define RTC_CNTL0                       (*(volatile unsigned char*)0x00004602)
    // [0]      Software reset
    #define RTC_CNTL0_RTCRST                0x01

    // [1]      Counter run/stop control
    #define RTC_CNTL0_RTCSTP                0x02

    // [2]      30second adjustment
    #define RTC_CNTL0_RTCADJ                0x04

    // [4]      24H/12H mode select
    #define RTC_CNTL0_RTC24H                0x10


// 0x00004603   RTC access control register
#define RTC_CNTL1                       (*(volatile unsigned char*)0x00004603)
    // [0]      Counter hold control
    #define RTC_CNTL1_RTCHLD                0x01

    // [1]      Counter busy flag
    #define RTC_CNTL1_RTCBSY                0x02


// 0x0000460f   RTC wakeup configure
#define RTC_WAKEUP                      (*(volatile unsigned char*)0x0000460f)
    // [0]      wake polarity
    #define RTC_WAKEUP_POL                  0x01

    // [1]      wakeup control
    #define RTC_WAKEUP_WAK                  0x02


// 0x00004614   RTC second register
#define RTC_SEC                         (*(volatile unsigned char*)0x00004614)
    // [3:0]    RTC 1second counter
    #define RTC_SEC_RTCSL                   0x0f

    // [6:4]    RTC 10second counter
    #define RTC_SEC_RTCSH                   0x70


// 0x00004615   RTC minute register
#define RTC_MIN                         (*(volatile unsigned char*)0x00004615)
    // [3:0]    RTC 1minute counter
    #define RTC_MIN_RTCMIL                  0x0f

    // [6:4]    RTC 10minute counter
    #define RTC_MIN_RTCMIH                  0x70


// 0x00004616   RTC hour register
#define RTC_HOUR                        (*(volatile unsigned char*)0x00004616)
    // [3:0]    RTC 1hour counter
    #define RTC_HOUR_RTCMIL                 0x0f

    // [5:4]    RTC 10hour counter
    #define RTC_HOUR_RTCMIH                 0x30

    // [6]      AM/PM indicator
    #define RTC_HOUR_RTCAP                  0x40


// 0x00004617   RTC day register
#define RTC_DAY                         (*(volatile unsigned char*)0x00004617)
    // [3:0]    RTC 1day counter
    #define RTC_DAY_RTCDL                   0x0f

    // [5:4]    RTC 10day counter
    #define RTC_DAY_RTCDH                   0x30


// 0x00004628   RTC month register
#define RTC_MONTH                       (*(volatile unsigned char*)0x00004628)
    // [3:0]    RTC 1month counter
    #define RTC_MONTH_RTCMOL                0x0f

    // [4]      RTC 10month counter
    #define RTC_MONTH_RTCMOH                0x10


// 0x00004629   RTC year register
#define RTC_YEAR                        (*(volatile unsigned char*)0x00004629)
    // [3:0]    RTC 1year counter
    #define RTC_YEAR_RTCYL                  0x0f

    // [7:4]    RTC 10year counter
    #define RTC_YEAR_RTCYH                  0xf0


// 0x0000462a   RTC days of week register
#define RTC_DAYWEEK                     (*(volatile unsigned char*)0x0000462a)
    // [2:0]    RTC days of week counter
    #define RTC_DAYWEEK_RTCWK               0x07


/*****************************************************************************
    T8      (0x00004800)    8bit timer Controller
*****************************************************************************/

// 0x00004800   8bit timer Ch0 input clock select register
#define T8_CLK0                         (*(volatile unsigned char*)0x00004800)
    // [3:0]    8bit timer Ch0 clock division ratio select
    #define T8_CLK0_P8TS                    0x0f

    // [4]      8bit timer Ch0 clock control
    #define T8_CLK0_P8TON                   0x10


// 0x00004801   8bit timer Ch0 reload data register
#define T8_RLD0                         (*(volatile unsigned char*)0x00004801)
    // [7:0]    8bit timer Ch0 reload data
    #define T8_RLD0_RLD                     0xff


// 0x00004802   8bit timer Ch0 counter data register
#define T8_PTD0                         (*(volatile unsigned char*)0x00004802)
    // [7:0]    8bit timer Ch0 counter data
    #define T8_PTD0_PTD                     0xff


// 0x00004803   8bit timer Ch0 control register
#define T8_CTL0                         (*(volatile unsigned char*)0x00004803)
    // [0]      8bit timer Ch0 Run/Stop control
    #define T8_CTL0_PTRUN                   0x01

    // [1]      8bit timer Ch0 preset
    #define T8_CTL0_PSET                    0x02


// 0x00004804   8bit timer Ch1 input clock select register
#define T8_CLK1                         (*(volatile unsigned char*)0x00004804)
    // [3:0]    8bit timer Ch1 clock division ratio select
    #define T8_CLK1_P8TS                    0x0f

    // [4]      8bit timer Ch1 clock control
    #define T8_CLK1_P8TON                   0x10


// 0x00004805   8bit timer Ch1 reload data register
#define T8_RLD1                         (*(volatile unsigned char*)0x00004805)
    // [7:0]    8bit timer Ch1 reload data
    #define T8_RLD1_RLD                     0xff


// 0x00004806   8bit timer Ch1 counter data register
#define T8_PTD1                         (*(volatile unsigned char*)0x00004806)
    // [7:0]    8bit timer Ch1 counter data
    #define T8_PTD1_PTD                     0xff


// 0x00004807   8bit timer Ch1 control register
#define T8_CTL1                         (*(volatile unsigned char*)0x00004807)
    // [0]      8bit timer Ch1 Run/Stop control
    #define T8_CTL1_PTRUN                   0x01

    // [1]      8bit timer Ch1 preset
    #define T8_CTL1_PSET                    0x02


// 0x00004808   8bit timer Ch2 input clock select register
#define T8_CLK2                         (*(volatile unsigned char*)0x00004808)
    // [3:0]    8bit timer Ch2 clock division ratio select
    #define T8_CLK2_P8TS                    0x0f

    // [4]      8bit timer Ch2 clock control
    #define T8_CLK2_P8TON                   0x10


// 0x00004809   8bit timer Ch2 reload data register
#define T8_RLD2                         (*(volatile unsigned char*)0x00004809)
    // [7:0]    8bit timer Ch2 reload data
    #define T8_RLD2_RLD                     0xff


// 0x0000480a   8bit timer Ch2 counter data register
#define T8_PTD2                         (*(volatile unsigned char*)0x0000480a)
    // [7:0]    8bit timer Ch2 counter data
    #define T8_PTD2_PTD                     0xff


// 0x0000480b   8bit timer Ch2 control register
#define T8_CTL2                         (*(volatile unsigned char*)0x0000480b)
    // [0]      8bit timer Ch2 Run/Stop control
    #define T8_CTL2_PTRUN                   0x01

    // [1]      8bit timer Ch2 preset
    #define T8_CTL2_PSET                    0x02


// 0x0000480c   8bit timer Ch3 input clock select register
#define T8_CLK3                         (*(volatile unsigned char*)0x0000480c)
    // [3:0]    8bit timer Ch3 clock division ratio select
    #define T8_CLK3_P8TS                    0x0f

    // [4]      8bit timer Ch3 clock control
    #define T8_CLK3_P8TON                   0x10


// 0x0000480d   8bit timer Ch3 reload data register
#define T8_RLD3                         (*(volatile unsigned char*)0x0000480d)
    // [7:0]    8bit timer Ch3 reload data
    #define T8_RLD3_RLD                     0xff


// 0x0000480e   8bit timer Ch3 counter data register
#define T8_PTD3                         (*(volatile unsigned char*)0x0000480e)
    // [7:0]    8bit timer Ch3 counter data
    #define T8_PTD3_PTD                     0xff


// 0x0000480f   8bit timer Ch3 control register
#define T8_CTL3                         (*(volatile unsigned char*)0x0000480f)
    // [0]      8bit timer Ch3 Run/Stop control
    #define T8_CTL3_PTRUN                   0x01

    // [1]      8bit timer Ch3 preset
    #define T8_CTL3_PSET                    0x02


/*****************************************************************************
    CMU     (0x00004900)    Clock Management Unit
*****************************************************************************/

// 0x00004900   System clock control register
#define CMU_SYSCLKCTL                   (*(volatile unsigned char*)0x00004900)
    // [1]      OSC3 Oscillator on/off
    #define CMU_SYSCLKCTL_SOSC3             0x02

    // [2]      OSC clock selection
    #define CMU_SYSCLKCTL_OSCSEL            0x04

    // [4]      Wakeup-wait function enable
    #define CMU_SYSCLKCTL_WAKEUPET          0x10

    // [6]      Wait-timer high speed mode
    #define CMU_SYSCLKCTL_TMHSP             0x40

    // [7]      OSC3 disable during SLEEP
    #define CMU_SYSCLKCTL_OSC3OFF           0x80


// 0x00004901   OSC3 Wait timer register
#define CMU_OSC3_WCNT                   (*(volatile unsigned char*)0x00004901)
    // [7:0]    OSC3 oscillation stabilizaton wait timer
    #define CMU_OSC3_WCNT_OSCTM             0xff


// 0x00004902   Noise filter control register
#define CMU_NF                          (*(volatile unsigned char*)0x00004902)
    // [0]      OSC3 input noise filter enable
    #define CMU_NF_OSC3NF                   0x01

    // [1]      Input port noise filter enable
    #define CMU_NF_INPORTNF                 0x02

    // [4]      DSIO input noise filter enable
    #define CMU_NF_DSINNF                   0x10


// 0x00004903   OSC3 clock divider register
#define CMU_OSC3DIV                     (*(volatile unsigned char*)0x00004903)
    // [2:0]    OSC3 clock divider
    #define CMU_OSC3DIV_OSC3DIV             0x07


// 0x00004904   LCDC clock divider register
#define CMU_LCDCDIV                     (*(volatile unsigned char*)0x00004904)
    // [3:0]    LCDC clock divider
    #define CMU_LCDCDIV_LCDCDIV             0x0f


// 0x00004905   CMU_CLK select register
#define CMU_CMUCLK                      (*(volatile unsigned char*)0x00004905)
    // [3:0]    CMU_CLK select
    #define CMU_CMUCLK_CMU_CLK_SEL          0x0f


// 0x00004906   Gated clock control register 0
#define CMU_GATEDCLK0                   (*(volatile unsigned char*)0x00004906)
    // [0]      PCLK of C17_Soc_Macro clock control
    #define CMU_GATEDCLK0_PCLK_SOC_EN       0x01

    // [1]      LCDC module main clock control
    #define CMU_GATEDCLK0_LCDC_CLK_EN       0x02

    // [2]      LCDC module SAPB I/F clock control
    #define CMU_GATEDCLK0_LCDC_SAPB_CLK_EN  0x04

    // [3]      LCDC module Host I/F clock control
    #define CMU_GATEDCLK0_LCDC_HOSTIF_CLK_EN  0x08

    // [4]      USB IP 48MHz clock control
    #define CMU_GATEDCLK0_USB_CLK_EN        0x10

    // [5]      USB SAPB I/F clock control
    #define CMU_GATEDCLK0_USB_SAPB_CLK_EN   0x20

    // [7]      FLASHC clock control in HALT mode
    #define CMU_GATEDCLK0_FLASHC_CLK_EN     0x80


// 0x00004907   Gated clock control register 1
#define CMU_GATEDCLK1                   (*(volatile unsigned char*)0x00004907)
    // [0]      MFT module clock control
    #define CMU_GATEDCLK1_MFT_CLK_EN        0x01

    // [1]      8-bit timer module clock control
    #define CMU_GATEDCLK1_T8_CLK_EN         0x02

    // [7]      SRAMC clock control in HALT mode
    #define CMU_GATEDCLK1_SRAMC_CLK_EN      0x80


// 0x00004908   Gated clock control register 2
#define CMU_GATEDCLK2                   (*(volatile unsigned char*)0x00004908)
    // [0]      RTC SAPB I/F clock control
    #define CMU_GATEDCLK2_RTC_SAPB_CLK_EN   0x01

    // [1]      PORT module normal clock source clock control
    #define CMU_GATEDCLK2_PORT_CLK_EN       0x02

    // [2]      Watch Dog timer clock control
    #define CMU_GATEDCLK2_WDT_CLK_EN        0x04

    // [3]      ADC clock control
    #define CMU_GATEDCLK2_ADC_CLK_EN        0x08

    // [4]      REMC module clock control
    #define CMU_GATEDCLK2_REMC_CLK_EN       0x10

    // [5]      SPI module clock control
    #define CMU_GATEDCLK2_SPI_CLK_EN        0x20


// 0x00004909   USB wait control register
#define CMU_USBWT                       (*(volatile unsigned char*)0x00004909)
    // [2:0]    USB regster access wait control
    #define CMU_USBWT_USBWT                 0x07

    // [5]      USB snooze control
    #define CMU_USBWT_USBSNZ                0x20


// 0x00004920   Clock control protect register
#define CMU_PROTECT                     (*(volatile unsigned char*)0x00004920)
    // [7:0]    Clock control register protect flag
    #define CMU_PROTECT_CLGP                0xff


/*****************************************************************************
    SRAMC   (0x00005000)    SRAMC controller
*****************************************************************************/

// 0x00005000   External Memory Static wait control register
#define SRAMC_EMSW                      (*(volatile unsigned short*)0x00005000)
    // [3:0]    #CE0 Static Wait Cycle
    #define SRAMC_EMSW_CE0SW                0x000f

    // [7:4]    #CE1 Static Wait Cycle
    #define SRAMC_EMSW_CE1SW                0x00f0

    // [11:8]   #CE2 Static Wait Cycle
    #define SRAMC_EMSW_CE2SW                0x0f00

    // [15:12]  #CE3 Static Wait Cycle
    #define SRAMC_EMSW_CE3SW                0xf000


// 0x00005004   External Memory Device size setting register
#define SRAMC_EMSZ                      (*(volatile unsigned short*)0x00005004)
    // [0]      #CE0 device size
    #define SRAMC_EMSZ_CE0                  0x0001

    // [1]      #CE1 device size
    #define SRAMC_EMSZ_CE1                  0x0002

    // [2]      #CE2 device size
    #define SRAMC_EMSZ_CE2                  0x0004

    // [3]      #CE3 device size
    #define SRAMC_EMSZ_CE3                  0x0008


// 0x00005008   External Memory Type Setting register
#define SRAMC_EMTS                      (*(volatile unsigned short*)0x00005008)
    // [0]      #CE0 memory type
    #define SRAMC_EMTS_CE0                  0x0001

    // [1]      #CE1 memory type
    #define SRAMC_EMTS_CE1                  0x0002

    // [2]      #CE2 memory type
    #define SRAMC_EMTS_CE2                  0x0004

    // [3]      #CE3 memory type
    #define SRAMC_EMTS_CE3                  0x0008


// 0x0000500c   External VRAM select register
#define SRAMC_EVSEL                     (*(volatile unsigned short*)0x0000500c)
    // [1:0]    EVRAM area select
    #define SRAMC_EVSEL_EVRAM               0x0003


// 0x00005010   Internal RAM Static Wait setting register
#define SRAMC_IRSW                      (*(volatile unsigned short*)0x00005010)
    // [0]      Internal RAM Static Wait Cycle
    #define SRAMC_IRSW_IRAM                 0x0001


// 0x00005014   MAC Mark Wait Setting register
#define SRAMC_MACW                      (*(volatile unsigned short*)0x00005014)
    // [0]      Mac Mark WaitCycle
    #define SRAMC_MACW_MACW                 0x0001


// 0x00005018   RTC Wait Setting register
#define SRAMC_RTCW                      (*(volatile unsigned short*)0x00005018)
    // [2:0]    RTC Wait Cycle
    #define SRAMC_RTCW_RTCW                 0x0007


/*****************************************************************************
    LCDC    (0x00005100)    LCD Controller
*****************************************************************************/

// 0x00005100	LCDC Frame Interrupt Enable Register
#define LCDC_FRMIE						(*(volatile unsigned short*)0x00005100)
	// [15] 	Frame interrupt enable
	#define LCDC_FRM_IE						0x8000


// 0x00005102	Status & power save Configuration register
#define LCDC_PS 						(*(volatile unsigned short*)0x00005102)
	// [1:0]	Power save configuration
	#define LCDC_PS_PSAVE					0x0003

	// [7]	   Vertical display status
	#define LCDC_PS_VNDPF					0x0080
	
	// [9]	   LCDC FIFO empty flag
	#define LCDC_FIFOEF 					0x0200
	
	// [15] 	Frame interrupt flag
	#define LCDC_FRMIF						0x8000


// 0x00005104   Horizontal Non-Display period register
#define LCDC_HND                        (*(volatile unsigned short*)0x00005104)
    // [4:0]    Determines Horizontal Non-Display period
    #define LCDC_HND_HNDPCNT                0x001f


// 0x00005106   Horizontal Panel Size register
#define LCDC_HSIZE                      (*(volatile unsigned short*)0x00005106)
    // [6:0]    Determines Horizontal Panel size
    #define LCDC_HSIZE_CHAR                 0x007f


// 0x00005108   Vertical Non-Display period register
#define LCDC_VNDP                       (*(volatile unsigned short*)0x00005108)
    // [5:0]    Determines Vartical Non-Display period
    #define LCDC_VNDP_VNDPCNT               0x003f


// 0x0000510a   Vertical Panel Size register
#define LCDC_VSIZE                      (*(volatile unsigned short*)0x0000510a)
    // [9:0]    Determines Vertical resolution of the panel in units of lines
    #define LCDC_VSIZE_LINE                 0x03ff


// 0x0000510c   MOD rate counter setting register
#define LCDC_MR                         (*(volatile unsigned short*)0x0000510c)
    // [5:0]    LCD MOD rate
    #define LCDC_MR_MOD                     0x003f


// 0x0000510e   LCD Controller Display Mode register1
#define LCDC_DMD1                       (*(volatile unsigned short*)0x0000510e)
    // [2:0]    Bit-per-pixel select
    #define LCDC_DMD1_BPP                   0x0007


// 0x00005110   LCD Controller Display Mode reguster2
#define LCDC_DMD2                       (*(volatile unsigned short*)0x00005110)
    // [8]      Display blank enable
    #define LCDC_DMD2_BLANK                 0x0100

    // [9]      Software video invert
    #define LCDC_DMD2_SWINV                 0x0200

    // [11:10]  LCD panel data width
    #define LCDC_DMD2_DWD                   0x0c00

    // [12]     SPI i/f mode
    #define LCDC_DMD2_SPIIF                 0x1000

    // [13]     FPSHIT mask enable
    #define LCDC_DMD2_FPMASK                0x2000

    // [15]     RAM build-in type LCD select
    #define LCDC_DMD2_RAMB                  0x8000


// 0x00005112   Screen Display Start address register1
#define LCDC_SADDR1                     (*(volatile unsigned short*)0x00005112)
    // [15:0]   Screen display start address low(15:0)
    #define LCDC_SADDR1_SADRL               0xffff


// 0x00005114   Screen Display Start address register2
#define LCDC_SADDR2                     (*(volatile unsigned short*)0x00005114)
    // [5:0]    Screen display start address high(21:16)
    #define LCDC_SADDR2_SADRH               0x003f

    // [15]     VRAM select
    #define LCDC_SADDR2_VRAM                0x8000


// 0x00005116   RAM build-in tyep LCD Panel write operation interface timing setting register
#define LCDC_RAMBW                      (*(volatile unsigned short*)0x00005116)
    // [1:0]    Access timing setting for AW8.
    #define LCDC_RAMBW_AW                   0x0003

    // [11:8]   Access timing setting for CCLW.
    #define LCDC_RAMBW_CCLW                 0x0f00

    // [15:12]  Access timing setting for CSHW.
    #define LCDC_RAMBW_CSHW                 0xf000


// 0x00005118   RAM build-in type LCD panel read operation interface timing setting register
#define LCDC_RAMBR                      (*(volatile unsigned short*)0x00005118)
    // [6:0]    Access timing setting for CCLR.
    #define LCDC_RAMBR_CCLR                 0x007f

    // [13:8]   Access timing setting for CSHR.
    #define LCDC_RAMBR_CSHR                 0x3f00


// 0x0000511a   RAM build-in type LCD panel control data access register
#define LCDC_RAMBCTL                    (*(volatile unsigned char*)0x0000511a)
    // [7:0]    control data
    #define LCDC_RAMBCTL_DATA               0xff


// 0x0000511b   RAM build-in type LCD panel display data access register
#define LCDC_RAMBDAT                    (*(volatile unsigned char*)0x0000511b)
    // [7:0]    display data
    #define LCDC_RAMBDAT_DATA               0xff


// 0x0000511c   LCDC SPI Status register
#define LCDC_SPISTAT                    (*(volatile unsigned short*)0x0000511c)
    // [0]      Transmit data buffer empty flag
    #define LCDC_SPISTAT_TBEF               0x0001

    // [2]      SPI transmit/receive operation status
    #define LCDC_SPISTAT_BUSY               0x0004


// 0x0000511e   LCDC SPI tansmit data register for control data writeing
#define LCDC_SPITXC                     (*(volatile unsigned char*)0x0000511e)
    // [7:0]    control data
    #define LCDC_SPITXC_DATA                0xff


// 0x0000511f   LCDC SPI tranmit data register for Display data writing.
#define LCDC_SPITXD                     (*(volatile unsigned char*)0x0000511f)
    // [7:0]    display data
    #define LCDC_SPITXD_DATA                0xff


// 0x00005122   LCDC SPI control register
#define LCDC_SPICTL                     (*(volatile unsigned short*)0x00005122)
    // [0]      SPI enable
    #define LCDC_SPICTL_SPIEN               0x0001

    // [4]      SPI transmit buffer empty interrupt enable
    #define LCDC_SPICTL_SPITIE              0x0010

    // [10:8]   SPI shift clock prescaler
    #define LCDC_SPICTL_SPIPSC              0x0700

    // [15]     SPI bit width data mode
    #define LCDC_SPICTL_DTWD                0x8000


// 0x00005124   LCDC LCD driver DMA setting register
#define LCDC_DMASET                     (*(volatile unsigned short*)0x00005124)
    // [7:0]    transfer count
    #define LCDC_DMASET_TRNCNT              0x00ff

    // [13:12]  Address control mode
    #define LCDC_DMASET_ADRCTL              0x3000

    // [15]     finish interrupt enable
    #define LCDC_DMASET_INTEN               0x8000


// 0x00005126   LCDC LCD driver DMA Control register
#define LCDC_DMACTL                     (*(volatile unsigned short*)0x00005126)
    // [0]      DMA start or Stop
    #define LCDC_DMACTL_DMAGO               0x0001

    // [15]     DMA finish flag
    #define LCDC_DMACTL_FINF                0x8000


/*****************************************************************************
    MFT     (0x00005200)    Multi function timer
*****************************************************************************/

// 0x00005200   16bit timer 0 Counter data register
#define MFT_TC0                         (*(volatile unsigned short*)0x00005200)
    // [15:0]   16bit timer 0 counter data
    #define MFT_TC0_TC                      0xffff


// 0x00005202   16bit timer 0 period setup register
#define MFT_PRD0                        (*(volatile unsigned short*)0x00005202)
    // [15:0]   16bit timer 0 period data
    #define MFT_PRD0_PRD                    0xffff


// 0x00005204   16bit timer 0 comparision setup register
#define MFT_CR0                         (*(volatile unsigned short*)0x00005204)
    // [15:0]   16bit timer 0 comparision data
    #define MFT_CR0_CR                      0xffff


// 0x00005206   16bit timer 0 control register
#define MFT_CTL0                        (*(volatile unsigned short*)0x00005206)
    // [0]      16bit timer 0 Run/Stop control
    #define MFT_CTL0_TMEN                   0x0001

    // [1]      16bit timer 0 reset
    #define MFT_CTL0_PRST                   0x0002

    // [2]      16bit timer 0 count pause
    #define MFT_CTL0_PAUSE                  0x0004

    // [5]      16bit timer 0 input clock selection
    #define MFT_CTL0_TCKS                   0x0020

    // [7]      16bit timer 0 comparison buffer
    #define MFT_CTL0_BUFEN                  0x0080

    // [10:8]   16bit timer 0 Prescaler selection
    #define MFT_CTL0_TPS                    0x0700

    // [11]     16bit timer 0 Prescaler on/off
    #define MFT_CTL0_TPSON                  0x0800


// 0x00005216   DA16 Chx comparton data
#define MFT_DACR0                       (*(volatile unsigned short*)0x00005216)
    // [15:0]   DA16 Chx comparison data
    #define MFT_DACR0_DA                    0xffff


// 0x0000521e   16bit timer 0 input/output control register
#define MFT_IOC0                        (*(volatile unsigned short*)0x0000521e)
    // [0]      16bit timer 0 output inversion
    #define MFT_IOC0_OINV                   0x0001

    // [1]      16bit timer 0 initial output level
    #define MFT_IOC0_INITOL                 0x0002

    // [2]      16bit timer 0 clock output control
    #define MFT_IOC0_PTM                    0x0004

    // [4]
    #define MFT_IOC0_IQA                    0x0010

    // [5]
    #define MFT_IOC0_PPIL                   0x0020

    // [6]
    #define MFT_IOC0_APIL                   0x0040


// 0x00005230   16bit timer 0 interrupt enable register
#define MFT_IE0                         (*(volatile unsigned short*)0x00005230)
    // [0]
    #define MFT_IE0_PPIE                    0x0001

    // [1]
    #define MFT_IE0_APIE                    0x0002

    // [2]
    #define MFT_IE0_CMPIE                   0x0004

    // [3]
    #define MFT_IE0_PRDIE                   0x0008


// 0x00005238   16bit timer 0 interrupt flag register
#define MFT_IF0                         (*(volatile unsigned short*)0x00005238)
    // [0]
    #define MFT_IF0_PPIFR                   0x0001

    // [1]
    #define MFT_IF0_APIFR                   0x0002

    // [2]
    #define MFT_IF0_CMPIFR                  0x0004

    // [3]
    #define MFT_IF0_PRDIFR                  0x0008


/*****************************************************************************
    I2S     (0x00005300)    I2S Interface
*****************************************************************************/

// 0x00005300   I2S Ch.0 control register
#define I2S_CONTRL_CH0                  (*(volatile unsigned short*)0x00005300)
    // [1:0]    I2S Ch0 output channel mode
    #define I2S_CONTRL_CH0_CHMD             0x0003

    // [3:2]    I2S Ch0 output Data Timing
    #define I2S_CONTRL_CH0_DTTMG            0x000c

    // [4]      I2S Ch0 output Enable
    #define I2S_CONTRL_CH0_I2SOUTEN         0x0010

    // [5]      I2S Ch0 output Data MSB/LSB format
    #define I2S_CONTRL_CH0_DTFORM           0x0020

    // [6]      I2S Ch0 output Bit clock polarity
    #define I2S_CONTRL_CH0_BCLKPOL          0x0040

    // [7]      I2S Ch0 output Word clock mode
    #define I2S_CONTRL_CH0_WCLKMD           0x0080

    // [8]      I2S Ch0 enable
    #define I2S_CONTRL_CH0_I2SEN            0x0100

    // [9]      I2S Ch0 Audio Data format
    #define I2S_CONTRL_CH0_AUDIOMD          0x0200

    // [10]     I2S Ch0 output Data Signed/Unsigned
    #define I2S_CONTRL_CH0_DTSIG            0x0400


// 0x00005302   I2S Ch.1 control register
#define I2S_CONTRL_CH1                  (*(volatile unsigned short*)0x00005302)
    // [0]      I2S Ch1 enable
    #define I2S_CONTRL_CH1_I2SEN            0x0001

    // [1]      I2S Ch1 Audio Data format
    #define I2S_CONTRL_CH1_AUDIOMD          0x0002

    // [3:2]    I2S CH1 input Data timing
    #define I2S_CONTRL_CH1_DTTMG            0x000c

    // [4]      I2S Ch1 input Bit clock polarity
    #define I2S_CONTRL_CH1_BCLKPOL          0x0010

    // [5]      I2S Ch1 Word clock mode
    #define I2S_CONTRL_CH1_WCLKMD           0x0020

    // [6]      I2S Bypass mode
    #define I2S_CONTRL_CH1_BYPMD            0x0040


// 0x00005304   MCLK divide ratio select register
#define I2S_DV_MCLK                     (*(volatile unsigned short*)0x00005304)
    // [5:0]    I2S MCLK divide ratio
    #define I2S_DV_MCLK_MCLK                0x003f

    // [15]     I2S MCLK Source
    #define I2S_DV_MCLK_MCLKSRC             0x8000


// 0x00005306   Audio clock divide ratio select register
#define I2S_DV_AUDIO_CLK                (*(volatile unsigned short*)0x00005306)
    // [7:0]    I2S Ch0 Bit Clock divide ratio
    #define I2S_DV_AUDIO_CLK_BCLKDIV        0x00ff

    // [11:8]   I2S Ch0 Bit clock cycle number
    #define I2S_DV_AUDIO_CLK_BCYCNUM0       0x0f00

    // [15:12]  I2S Ch1 bit clock cycle number
    #define I2S_DV_AUDIO_CLK_BCYCNUM1       0xf000


// 0x00005308   I2S Start/Stop register
#define I2S_START                       (*(volatile unsigned short*)0x00005308)
    // [0]      I2S Ch0 Start/Stop
    #define I2S_START_START0                0x0001

    // [7]      I2S Ch0 busy
    #define I2S_START_BUSY                  0x0080

    // [8]      I2S Ch1 Start/Stop
    #define I2S_START_START1                0x0100


// 0x0000530a   I2S FIFO Status register
#define I2S_FIFO_STS                    (*(volatile unsigned short*)0x0000530a)
    // [0]      I2S Ch0 FIFO empty flag
    #define I2S_FIFO_STS_FIFOEF0            0x0001

    // [1]      I2S Ch0 FiFO full flag
    #define I2S_FIFO_STS_FIFOFF0            0x0002

    // [4:2]    I2S Ch0 FIFO State machine
    #define I2S_FIFO_STS_FIFOST0            0x001c

    // [8]      I2S Ch1 FIFO empty flag
    #define I2S_FIFO_STS_FIFOEF1            0x0100

    // [9]      I2S Ch1 FIFO full flag
    #define I2S_FIFO_STS_FIFOFF1            0x0200


// 0x0000530c   I2S interrupt mode register
#define I2S_INT_MOD                     (*(volatile unsigned short*)0x0000530c)
    // [0]      I2S Ch0 interrupt enable
    #define I2S_INT_MOD_INTEN0              0x0001

    // [1]      I2S Ch1 interrupt enable
    #define I2S_INT_MOD_INTEN1              0x0002

    // [3:2]    I2S Ch0 interrupt mode selection
    #define I2S_INT_MOD_INTSEL0             0x000c

    // [5:4]    I2S Ch1 interrupt mode selection
    #define I2S_INT_MOD_INTSEL1             0x0030


// 0x00005310   I2S output channel FIFO register
#define I2S_FIFOCH0                     (*(volatile unsigned short*)0x00005310)
    // [15:0]   I2S output channel FIFO data
    #define I2S_FIFOCH0_FIFODT0             0xffff


// 0x00005310   I2S output channel FIFO register
    // [23:0]   I2S output channel FIFO data

// 0x00005314   I2S input channel FIFO register
#define I2S_FIFOCH1                     (*(volatile unsigned short*)0x00005314)
    // [15:0]   I2S input channel FIFO data
    #define I2S_FIFOCH1_FIFODT1             0xffff


// 0x00005314   I2S input channel FIFO register
    // [23:0]   I2S input channel FIFO data

/*****************************************************************************
    REMC    (0x00005400)    Remote control Controller
*****************************************************************************/

// 0x00005400   REMC Prescaler register
#define REMC_PSC                        (*(volatile unsigned short*)0x00005400)
    // [1:0]    Prescaler division ratio
    #define REMC_PSC_PSDIV                  0x0003

    // [2]      Prescaler clock on/off
    #define REMC_PSC_PSON                   0x0004


// 0x00005404   REMC configuration register
#define REMC_CNF                        (*(volatile unsigned short*)0x00005404)
    // [0]      Envelope conter underflow interrupt enable
    #define REMC_CNF_UIE                    0x0001

    // [1]      Falling edge interrupt enable
    #define REMC_CNF_FIE                    0x0002

    // [2]      Rising edge interrupt enable
    #define REMC_CNF_RIE                    0x0004

    // [4]      Envelope conter underflow flag
    #define REMC_CNF_UIF                    0x0010

    // [5]      Falling edge flag
    #define REMC_CNF_FIF                    0x0020

    // [6]      Rising edge flag
    #define REMC_CNF_RIF                    0x0040

    // [7]      Transmit / receive select
    #define REMC_CNF_MODE                   0x0080


// 0x00005408   REMC control register
#define REMC_CTL                        (*(volatile unsigned short*)0x00005408)
    // [0]      REMC start/stop
    #define REMC_CTL_REMST                  0x0001


// 0x0000540c   REMC Carrier load register
#define REMC_CARL                       (*(volatile unsigned short*)0x0000540c)
    // [7:0]    Carrier Low
    #define REMC_CARL_CLDL                  0x00ff

    // [15:8]   Carrier High
    #define REMC_CARL_CLDH                  0xff00


// 0x0000540e   REMC Envelope load register
#define REMC_ENVL                       (*(volatile unsigned short*)0x0000540e)
    // [7:0]    Envelope load LS-Byte(pulse width)
    #define REMC_ENVL_ELDL                  0x00ff

    // [15:8]   Envelope load MS-Byte(pulse width)
    #define REMC_ENVL_ELDH                  0xff00


// 0x00005410   REMC Envelope Capture register
#define REMC_ENVC                       (*(volatile unsigned short*)0x00005410)
    // [7:0]    Capture MS-Byte(pulse width)
    #define REMC_ENVC_ECPL                  0x00ff

    // [15:8]   Capture LS-Byte(pulse width)
    #define REMC_ENVC_ECPH                  0xff00


/*****************************************************************************
    ADC     (0x00005500)    AD Controller
*****************************************************************************/

// 0x00005520   A/D Clock control register
#define ADC_CLKCTL                      (*(volatile unsigned short*)0x00005520)
    // [2:0]    A/D converter clock dividion ratio select
    #define ADC_CLKCTL_PSAD                 0x0007

    // [3]      A/D converter clock control
    #define ADC_CLKCTL_PSONAD               0x0008


// 0x00005540   A/D Conversion result register
#define ADC_ADD                         (*(volatile unsigned short*)0x00005540)
    // [9:0]    A/D converted data
    #define ADC_ADD_ADD                     0x03ff


// 0x00005542   A/D Trigger/Channel select register
#define ADC_TRIG_CHNL                   (*(volatile unsigned short*)0x00005542)
    // [2:0]    A/D conversion channel status
    #define ADC_TRIG_CHNL_CH                0x0007

    // [4:3]    A/D conversion trigger selection
    #define ADC_TRIG_CHNL_TS                0x0018

    // [5]      A/D conversion mode selection
    #define ADC_TRIG_CHNL_MS                0x0020

    // [10:8]   A/D converter start channel selection
    #define ADC_TRIG_CHNL_CS                0x0700

    // [13:11]  A/D converter end channel selection
    #define ADC_TRIG_CHNL_CE                0x3800


// 0x00005544   A/D Control/Status register
#define ADC_EN_SMPL_STAT                (*(volatile unsigned short*)0x00005544)
    // [0]      Over write error flag
    #define ADC_EN_SMPL_STAT_OWE            0x0001

    // [1]      A/D conversion control/status
    #define ADC_EN_SMPL_STAT_ADST           0x0002

    // [2]      A/D enable
    #define ADC_EN_SMPL_STAT_ADE            0x0004

    // [3]      Conversion complete flag
    #define ADC_EN_SMPL_STAT_ADF            0x0008

    // [4]      Conversion complete interrupt enable
    #define ADC_EN_SMPL_STAT_CNVINTEN       0x0010

    // [5]      Out-of-rage interrupt enable
    #define ADC_EN_SMPL_STAT_CMPINTEN       0x0020

    // [6]      interrupt signal mode
    #define ADC_EN_SMPL_STAT_INTMODE        0x0040

    // [9:8]    input signal sampling time setup
    #define ADC_EN_SMPL_STAT_ST             0x0300

    // [10]     Lowe limit comparison status
    #define ADC_EN_SMPL_STAT_ADLWRST        0x0400

    // [11]     Lupper limit comparison status
    #define ADC_EN_SMPL_STAT_ADUPRST        0x0800

    // [14:12]  Upper/lowe limit comparison channel selection
    #define ADC_EN_SMPL_STAT_ADCMP          0x7000

    // [15]     Upper/lowe limit comparison channel enable
    #define ADC_EN_SMPL_STAT_ADCMPE         0x8000


// 0x00005546   A/D channel status flag register
#define ADC_END                         (*(volatile unsigned short*)0x00005546)
    // [0]      Ch0 conversion complete flag
    #define ADC_END_ADF0                    0x0001

    // [1]      Ch1 conversion complete flag
    #define ADC_END_ADF1                    0x0002

    // [2]      Ch2 conversion complete flag
    #define ADC_END_ADF2                    0x0004

    // [3]      Ch3 conversion complete flag
    #define ADC_END_ADF3                    0x0008

    // [4]      Ch4 conversion complete flag
    #define ADC_END_ADF4                    0x0010

    // [5]      Ch5 conversion complete flag
    #define ADC_END_ADF5                    0x0020

    // [6]      Ch6 conversion complete flag
    #define ADC_END_ADF6                    0x0040

    // [7]      Ch7 conversion complete flag
    #define ADC_END_ADF7                    0x0080

    // [8]      Ch0 overwrite error flag
    #define ADC_END_OWE0                    0x0100

    // [9]      Ch1 overwrite error flag
    #define ADC_END_OWE1                    0x0200

    // [10]     Ch2 overwrite error flag
    #define ADC_END_OWE2                    0x0400

    // [11]     Ch3 overwrite error flag
    #define ADC_END_OWE3                    0x0800

    // [12]     Ch4 overwrite error flag
    #define ADC_END_OWE4                    0x1000

    // [13]     Ch5 overwrite error flag
    #define ADC_END_OWE5                    0x2000

    // [14]     Ch6 overwrite error flag
    #define ADC_END_OWE6                    0x4000

    // [15]     Ch7 overwrite error flag
    #define ADC_END_OWE7                    0x8000


// 0x00005548   A/D Ch0 conversion result buffer register
#define ADC_CH0BUF                      (*(volatile unsigned short*)0x00005548)
    // [9:0]    A/D Ch0 converted data
    #define ADC_CH0BUF_AD0BUF               0x03ff


// 0x0000554a   A/D Ch1 conversion result buffer register
#define ADC_CH1BUF                      (*(volatile unsigned short*)0x0000554a)
    // [9:0]    A/D Ch1 converted data
    #define ADC_CH1BUF_AD1BUF               0x03ff


// 0x0000554c   A/D Ch2 conversion result buffer register
#define ADC_CH2BUF                      (*(volatile unsigned short*)0x0000554c)
    // [9:0]    A/D Ch2 converted data
    #define ADC_CH2BUF_AD2BUF               0x03ff


// 0x0000554e   A/D Ch3 conversion result buffer register
#define ADC_CH3BUF                      (*(volatile unsigned short*)0x0000554e)
    // [9:0]    A/D Ch3 converted data
    #define ADC_CH3BUF_AD3BUF               0x03ff


// 0x00005550   A/D Ch4 conversion result buffer register
#define ADC_CH4BUF                      (*(volatile unsigned short*)0x00005550)
    // [9:0]    A/D Ch4 converted data
    #define ADC_CH4BUF_AD4BUF               0x03ff


// 0x00005552   A/D Ch5 conversion result buffer register
#define ADC_CH5BUF                      (*(volatile unsigned short*)0x00005552)
    // [9:0]    A/D Ch5 converted data
    #define ADC_CH5BUF_AD5BUF               0x03ff


// 0x00005554   A/D Ch6 conversion result buffer register
#define ADC_CH6BUF                      (*(volatile unsigned short*)0x00005554)
    // [9:0]    A/D Ch6 converted data
    #define ADC_CH6BUF_AD6BUF               0x03ff


// 0x00005556   A/D Ch7 conversion result buffer register
#define ADC_CH7BUF                      (*(volatile unsigned short*)0x00005556)
    // [9:0]    A/D Ch7 converted data
    #define ADC_CH7BUF_AD7BUF               0x03ff


// 0x00005558   A/D Upper limit value register
#define ADC_UPPER                       (*(volatile unsigned short*)0x00005558)
    // [9:0]    A/D conversion upper limit value
    #define ADC_UPPER_ADUPR                 0x03ff


// 0x0000555a   A/D Lower limit value register
#define ADC_LOWER                       (*(volatile unsigned short*)0x0000555a)
    // [9:0]    A/D conversion lower limit value
    #define ADC_LOWER_ADLWR                 0x03ff


// 0x0000555c   A/D Conversion complete interrupt mask register
#define ADC_CH07_INTMASK                (*(volatile unsigned short*)0x0000555c)
    // [0]      Ch0 conversion complete interrupt mask
    #define ADC_CH07_INTMASK_INTMASK0       0x0001

    // [1]      Ch1 conversion complete interrupt mask
    #define ADC_CH07_INTMASK_INTMASK1       0x0002

    // [2]      Ch2 conversion complete interrupt mask
    #define ADC_CH07_INTMASK_INTMASK2       0x0004

    // [3]      Ch3 conversion complete interrupt mask
    #define ADC_CH07_INTMASK_INTMASK3       0x0008

    // [4]      Ch4 conversion complete interrupt mask
    #define ADC_CH07_INTMASK_INTMASK4       0x0010

    // [5]      Ch5 conversion complete interrupt mask
    #define ADC_CH07_INTMASK_INTMASK5       0x0020

    // [6]      Ch6 conversion complete interrupt mask
    #define ADC_CH07_INTMASK_INTMASK6       0x0040

    // [7]      Ch7 conversion complete interrupt mask
    #define ADC_CH07_INTMASK_INTMASK7       0x0080


// 0x0000555e   A/D Converter mode select/internal status register
#define ADC_ADVMODE                     (*(volatile unsigned short*)0x0000555e)
    // [3:0]    Internal counter value
    #define ADC_ADVMODE_ICONTER             0x000f

    // [5:4]    Internal status
    #define ADC_ADVMODE_ISTATE              0x0030

    // [8]      Standard/Advanced mode selection
    #define ADC_ADVMODE_ADCADV              0x0100


/*****************************************************************************
    WDT     (0x00005600)    Watchdog Timer Controller
*****************************************************************************/

// 0x00005600   Watchdog Timer Write-Protect register
#define WDT_WP                          (*(volatile unsigned short*)0x00005600)
    // [15:0]   Watchdeog timer register write-protect
    #define WDT_WP_WDPTC                    0xffff


// 0x00005662   Watchdog timer Enable register
#define WDT_EN                          (*(volatile unsigned short*)0x00005662)
    // [0]      Watchdog timer RESET enbale
    #define WDT_EN_RESEN                    0x0001

    // [1]      Watchdog timer NMI enable
    #define WDT_EN_NMIEN                    0x0002

    // [4]      Watchdog timer Run/Stop control
    #define WDT_EN_RUNSTP                   0x0010

    // [5]      Watchdog timer clock output control
    #define WDT_EN_CLKEN                    0x0020

    // [6]      Watchdog timer input clock select
    #define WDT_EN_CLKSEL                   0x0040


// 0x00005664   Watchdog timer comparison data setup register 0
#define WDT_COMP_LOW                    (*(volatile unsigned short*)0x00005664)
    // [15:0]   Watchdog timer comparison data
    #define WDT_COMP_LOW_CMPDT              0xffff


// 0x00005666   Watchdog timer comparison data setup register 1
#define WDT_COMP_HIGH                   (*(volatile unsigned short*)0x00005666)
    // [13:0]   Watchdog timer comparison data
    #define WDT_COMP_HIGH_CMPDT             0x3fff


// 0x00005668   Watchdog timer count register 0
#define WDT_CNT_LOW                     (*(volatile unsigned short*)0x00005668)
    // [15:0]   Watchdog timer counter data
    #define WDT_CNT_LOW_CTRDT               0xffff


// 0x0000566a   Watchdog timer count register 1
#define WDT_CNT_HIGH                    (*(volatile unsigned short*)0x0000566a)
    // [13:0]   Watchdog timer counter data
    #define WDT_CNT_HIGH_CTRDT              0x3fff


// 0x0000566c   Watchdog timer control register
#define WDT_CNTL                        (*(volatile unsigned short*)0x0000566c)
    // [0]      Watchdog timer reset
    #define WDT_CNTL_WDRESEN                0x0001


/*****************************************************************************
    SPI1    (0x00005700)    SPI Ch1 Controller
*****************************************************************************/

// 0x00005700   SPI Status register
#define SPI1_ST                         (*(volatile unsigned short*)0x00005700)
    // [0]      Transmit data buffer empty flag
    #define SPI1_ST_SPTBE                   0x0001

    // [1]      Receive data buffer full flag
    #define SPI1_ST_SPRBF                   0x0002

    // [2]      Transfer busy flag(master)
    #define SPI1_ST_SPBSY                   0x0004


// 0x00005702   SPI Transmit Data register
#define SPI1_TXD                        (*(volatile unsigned short*)0x00005702)
    // [7:0]    SPI transmit data buffer
    #define SPI1_TXD_SPTDB                  0x00ff


// 0x00005704   SPI Receive Data register
#define SPI1_RXD                        (*(volatile unsigned short*)0x00005704)
    // [7:0]    SPI receive data buffer
    #define SPI1_RXD_SPRDB                  0x00ff


// 0x00005706   SPI Control register
#define SPI1_CTL                        (*(volatile unsigned short*)0x00005706)
    // [0]      SPI enable
    #define SPI1_CTL_SPEN                   0x0001

    // [1]      Master/Slave mode select
    #define SPI1_CTL_MSSL                   0x0002

    // [2]      Clock polarity select
    #define SPI1_CTL_CPOL                   0x0004

    // [3]      Clock phase selct
    #define SPI1_CTL_CPHA                   0x0008

    // [4]      Transmit data buffer empty int. enable
    #define SPI1_CTL_SPTIE                  0x0010

    // [5]      Receive data buffer full int. enable
    #define SPI1_CTL_SPRIE                  0x0020


// 0x00005708   SPI Clock register
#define SPI1_CLK                        (*(volatile unsigned short*)0x00005708)
    // [3:0]    8bit timer x clock division raito select
    #define SPI1_CLK_P8TS                   0x000f

    // [4]      8bit timer x clock control
    #define SPI1_CLK_P8TON                  0x0010


/*****************************************************************************
    FLSHC   (0x00005800)    Flash Controller
*****************************************************************************/

// 0x00005800   Flash controller control  register
#define FLSHC_CTL                       (*(volatile unsigned short*)0x00005800)
    // [0]      Flash write enable
    #define FLSHC_CTL_WREN                  0x0001

    // [1]      Flash sector erase enable
    #define FLSHC_CTL_SEEN                  0x0002

    // [2]      Flash chip erase enable
    #define FLSHC_CTL_CEEN                  0x0004

    // [8]      Start flash erase
    #define FLSHC_CTL_STRE                  0x0100

    // [9]      Start to wait hold time for erase or write
    #define FLSHC_CTL_STRH                  0x0200

    // [10]     Stop erase or write
    #define FLSHC_CTL_STP                   0x0400

    // [15]     Flash status flag
    #define FLSHC_CTL_STS                   0x8000


// 0x00005802   Flash controller address register
#define FLSHC_ADDR                      (*(volatile unsigned short*)0x00005802)
    // [6:0]    Flash address[15:9] for sector erase
    #define FLSHC_ADDR_FADR                 0x007f


// 0x00005804   Flash controller wait register
#define FLSHC_WAIT                      (*(volatile unsigned short*)0x00005804)
    // [2:0]    Wait cycle for flash read
    #define FLSHC_WAIT_FWT                  0x0007


// 0x00005810   Flash controller protect register
#define FLSHC_PROT                      (*(volatile unsigned short*)0x00005810)
    // [7:0]    Flash control protect
    #define FLSHC_PROT_FPRT                 0x00ff


// 0x00005814   Trap table base address low register
#define FLSHC_TTBRL                     (*(volatile unsigned short*)0x00005814)
    // [15:8]   Trap table base address[15:8]
    #define FLSHC_TTBRL_TTBR                0xff00


// 0x00005816   Trap table base address high register
#define FLSHC_TTBRH                     (*(volatile unsigned short*)0x00005816)
    // [7:0]    Trap table base address[23:16]
    #define FLSHC_TTBRH_TTBR                0x00ff


#endif	/*	___REG_801_H___	*/
