/***************************************************************************
*
*	File name	: itc_api.h
*	Function	: APIs for ITC
*	Revision	:
*		10/04/2007	Nariai		First revision
*
****************************************************************************/
#ifndef	__ITC_API_H__
#define	__ITC_API_H__

// Interrupt enable
#define	ITC_INT_DISABLE		0
#define	ITC_INT_ENABLE		1

// Trigger mode (TM)
#define	ITC_TM_PULSE		0
#define	ITC_TM_LEVEL		1

// Trigger polarity (TP)
#define	ITC_TP_NEGATIVE		0
#define	ITC_TP_POSITIVE		1

// Function enable
#define	ITC_FUNC_DISABLE	0
#define	ITC_FUNC_ENABLE		1


// Additional interrupt enable
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		mft			: 1;
		unsigned short		reserved_1	: 1;
		unsigned short		adcRange	: 1;
		unsigned short		adcEnd		: 1;
		unsigned short		rtc			: 1;
		unsigned short		t8Ch0		: 1;
		unsigned short		t8Ch1		: 1;
		unsigned short		t8Ch2		: 1;
		unsigned short		t8Ch3		: 1;
		unsigned short		lcdc		: 1;
		unsigned short		espi		: 1;
		unsigned short		usb			: 1;
		unsigned short		i2sTran		: 1;
		unsigned short		i2sRcv		: 1;
		unsigned short		remc		: 1;
		unsigned short		reserved_2	: 1;
	} bit;
} U_ITC_AIEN;

// Addtional interrupt level setup 0
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		mft			: 3;
		unsigned short		reserved	:13;
	} bit;
} U_ITC_AILV0;

// Addtional interrupt level setup 1
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		adcRange	: 3;
		unsigned short		reserved_1	: 5;
		unsigned short		adcEnd		: 3;
		unsigned short		reserved_2	: 5;
	} bit;
} U_ITC_AILV1;

// Addtional interrupt level setup 2
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		rtc			: 3;
		unsigned short		reserved_1	: 5;
		unsigned short		t8Ch0		: 3;
		unsigned short		reserved_2	: 5;
	} bit;
} U_ITC_AILV2;

// Addtional interrupt level setup 3
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		t8Ch1		: 3;
		unsigned short		reserved_1	: 5;
		unsigned short		t8Ch2		: 3;
		unsigned short		reserved_2	: 5;
	} bit;
} U_ITC_AILV3;

// Addtional interrupt level setup 4
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		t8Ch3		: 3;
		unsigned short		reserved_1	: 5;
		unsigned short		lcdc		: 3;
		unsigned short		reserved_2	: 5;
	} bit;
} U_ITC_AILV4;

// Addtional interrupt level setup 5
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		espi		: 3;
		unsigned short		reserved_1	: 5;
		unsigned short		usb			: 3;
		unsigned short		reserved_2	: 5;
	} bit;
} U_ITC_AILV5;

// Addtional interrupt level setup 6
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		i2sTran		: 3;
		unsigned short		reserved_1	: 5;
		unsigned short		i2sRcv		: 3;
		unsigned short		reserved_2	: 5;
	} bit;
} U_ITC_AILV6;

// Addtional interrupt level setup 7
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		remc		: 3;
		unsigned short		reserved	:13;
	} bit;
} U_ITC_AILV7;

// Interrupt enable
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		port0		: 1;
		unsigned short		port1		: 1;
		unsigned short		port2		: 1;
		unsigned short		port3		: 1;
		unsigned short		port4		: 1;
		unsigned short		port5		: 1;
		unsigned short		port6		: 1;
		unsigned short		port7		: 1;
		unsigned short		clgT16U		: 1;
		unsigned short		reserved_1	: 1;
		unsigned short		clgT8S		: 1;
		unsigned short		clgT8I		: 1;
		unsigned short		uart		: 1;
		unsigned short		reserved_2	: 1;
		unsigned short		spi			: 1;
		unsigned short		i2c			: 1;
	} bit;
} U_ITC_IEN;

// External interrupt level setup 0
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		port0		: 3;
		unsigned short		reserved_1	: 1;
		unsigned short		port0_TM	: 1;
		unsigned short		port0_TP	: 1;
		unsigned short		reserved_2	: 2;
		unsigned short		port1		: 3;
		unsigned short		reserved_3	: 1;
		unsigned short		port1_TM	: 1;
		unsigned short		port1_TP	: 1;
		unsigned short		reserved_4	: 2;
	} bit;
} U_ITC_ELV0;

// External interrupt level setup 1
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		port2		: 3;
		unsigned short		reserved_1	: 1;
		unsigned short		port2_TM	: 1;
		unsigned short		port2_TP	: 1;
		unsigned short		reserved_2	: 2;
		unsigned short		port3		: 3;
		unsigned short		reserved_3	: 1;
		unsigned short		port3_TM	: 1;
		unsigned short		port3_TP	: 1;
		unsigned short		reserved_4	: 2;
	} bit;
} U_ITC_ELV1;

// External interrupt level setup 2
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		port4		: 3;
		unsigned short		reserved_1	: 1;
		unsigned short		port4_TM	: 1;
		unsigned short		port4_TP	: 1;
		unsigned short		reserved_2	: 2;
		unsigned short		port5		: 3;
		unsigned short		reserved_3	: 1;
		unsigned short		port5_TM	: 1;
		unsigned short		port5_TP	: 1;
		unsigned short		reserved_4	: 2;
	} bit;
} U_ITC_ELV2;

// External interrupt level setup 3
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		port6		: 3;
		unsigned short		reserved_1	: 1;
		unsigned short		port6_TM	: 1;
		unsigned short		port6_TP	: 1;
		unsigned short		reserved_2	: 2;
		unsigned short		port7		: 3;
		unsigned short		reserved_3	: 1;
		unsigned short		port7_TM	: 1;
		unsigned short		port7_TP	: 1;
		unsigned short		reserved_4	: 2;
	} bit;
} U_ITC_ELV3;

// Internal interrupt level setup 0
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		clgT16U		: 3;
		unsigned short		reserved_1	:13;
	} bit;
} U_ITC_ILV0;

// Internal interrupt level setup 1
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		clgT8S		: 3;
		unsigned short		reserved_1	: 5;
		unsigned short		clgT8I		: 3;
		unsigned short		reserved_2	: 5;
	} bit;
} U_ITC_ILV1;

// Internal interrupt level setup 2
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		uart		: 3;
		unsigned short		reserved_1	:13;
	} bit;
} U_ITC_ILV2;

// Internal interrupt level setup 3
typedef union {
	unsigned short			reg;
	struct {
		unsigned short		spi			: 3;
		unsigned short		reserved_1	: 5;
		unsigned short		i2c			: 3;
		unsigned short		reserved_2	: 5;
	} bit;
} U_ITC_ILV3;


// ITC configuration
typedef struct {

	U_ITC_AIEN		addIntEn;
	U_ITC_AILV0		addIntLv0;
	U_ITC_AILV1		addIntLv1;
	U_ITC_AILV2		addIntLv2;
	U_ITC_AILV3		addIntLv3;
	U_ITC_AILV4		addIntLv4;
	U_ITC_AILV5		addIntLv5;
	U_ITC_AILV6		addIntLv6;
	U_ITC_AILV7		addIntLv7;

	U_ITC_IEN		intEn;
	U_ITC_ELV0		extIntLv0;
	U_ITC_ELV1		extIntLv1;
	U_ITC_ELV2		extIntLv2;
	U_ITC_ELV3		extIntLv3;
	U_ITC_ILV0		inIntLv0;
	U_ITC_ILV1		inIntLv1;
	U_ITC_ILV2		inIntLv2;
	U_ITC_ILV3		inIntLv3;

	unsigned char	funcEnable;
} T_ITC_CFG;


// Macro function
// For additional interrupt flag register
#define	ItcClrAddIntFlag(x)			(ITC_AITFT = x)
#define	ItcGetAddIntFlag()			(ITC_AITFT)
#define	ItcClrMftInt()				(ITC_AITFT = ITC_AITFT_AIFT0)
#define	ItcClrAdcRangeInt()			(ITC_AITFT = ITC_AITFT_AIFT2)
#define	ItcClrAdcEndInt()			(ITC_AITFT = ITC_AITFT_AIFT3)
#define	ItcClrRtcInt()				(ITC_AITFT = ITC_AITFT_AIFT4)
#define	ItcClrT8Ch0Int()			(ITC_AITFT = ITC_AITFT_AIFT5)
#define	ItcClrT8Ch1Int()			(ITC_AITFT = ITC_AITFT_AIFT6)
#define	ItcClrT8Ch2Int()			(ITC_AITFT = ITC_AITFT_AIFT7)
#define	ItcClrT8Ch3Int()			(ITC_AITFT = ITC_AITFT_AIFT8)
#define	ItcClrLcdcInt()				(ITC_AITFT = ITC_AITFT_AIFT9)
#define	ItcClrEspiInt()				(ITC_AITFT = ITC_AITFT_AIFT10)
#define	ItcClrUsbInt()				(ITC_AITFT = ITC_AITFT_AIFT11)
#define	ItcClrI2sTranInt()			(ITC_AITFT = ITC_AITFT_AIFT12)
#define	ItcClrI2sRcvInt()			(ITC_AITFT = ITC_AITFT_AIFT13)
#define	ItcClrRemcInt()				(ITC_AITFT = ITC_AITFT_AIFT14)
#define	ItcGetMftInt()				(ITC_AITFT & ITC_AITFT_AIFT0)
#define	ItcGetAdcRangeInt()			((ITC_AITFT & ITC_AITFT_AIFT2)  >> 2)
#define	ItcGetAdcEndInt()			((ITC_AITFT & ITC_AITFT_AIFT3)  >> 3)
#define	ItcGetRtcInt()				((ITC_AITFT & ITC_AITFT_AIFT4)  >> 4)
#define	ItcGetT8Ch0Int()			((ITC_AITFT & ITC_AITFT_AIFT5)  >> 5)
#define	ItcGetT8Ch1Int()			((ITC_AITFT & ITC_AITFT_AIFT6)  >> 6)
#define	ItcGetT8Ch2Int()			((ITC_AITFT & ITC_AITFT_AIFT7)  >> 7)
#define	ItcGetT8Ch3Int()			((ITC_AITFT & ITC_AITFT_AIFT8)  >> 8)
#define	ItcGetLcdcInt()				((ITC_AITFT & ITC_AITFT_AIFT9)  >> 9)
#define	ItcGetEspiInt()				((ITC_AITFT & ITC_AITFT_AIFT10) >> 10)
#define	ItcGetUsbInt()				((ITC_AITFT & ITC_AITFT_AIFT11) >> 11)
#define	ItcGetI2sTranInt()			((ITC_AITFT & ITC_AITFT_AIFT12) >> 12)
#define	ItcGetI2sRcvInt()			((ITC_AITFT & ITC_AITFT_AIFT13) >> 13)
#define	ItcGetRemcInt()				((ITC_AITFT & ITC_AITFT_AIFT14) >> 14)

// For additional interrupt enable register
#define	ItcSetAddIntEnable(x)		(ITC_AITEN = x)
#define	ItcGetAddIntEnable()		(ITC_AITEN)
#define	ItcMftIntEnable()			(ITC_AITEN |= ITC_AITEN_AIEN0)
#define	ItcAdcRangeIntEnable()		(ITC_AITEN |= ITC_AITEN_AIEN2)
#define	ItcAdcEndIntEnable()		(ITC_AITEN |= ITC_AITEN_AIEN3)
#define	ItcRtcIntEnable()			(ITC_AITEN |= ITC_AITEN_AIEN4)
#define	ItcT8Ch0IntEnable()			(ITC_AITEN |= ITC_AITEN_AIEN5)
#define	ItcT8Ch1IntEnable()			(ITC_AITEN |= ITC_AITEN_AIEN6)
#define	ItcT8Ch2IntEnable()			(ITC_AITEN |= ITC_AITEN_AIEN7)
#define	ItcT8Ch3IntEnable()			(ITC_AITEN |= ITC_AITEN_AIEN8)
#define	ItcLcdcIntEnable()			(ITC_AITEN |= ITC_AITEN_AIEN9)
#define	ItcEspiIntEnable()			(ITC_AITEN |= ITC_AITEN_AIEN10)
#define	ItcUsbIntEnable()			(ITC_AITEN |= ITC_AITEN_AIEN11)
#define	ItcI2sTranIntEnable()		(ITC_AITEN |= ITC_AITEN_AIEN12)
#define	ItcI2sRcvIntEnable()		(ITC_AITEN |= ITC_AITEN_AIEN13)
#define	ItcRemcIntEnable()			(ITC_AITEN |= ITC_AITEN_AIEN14)
#define	ItcMftIntDisable()			(ITC_AITEN &= ~(ITC_AITEN_AIEN0))
#define	ItcAdcRangeIntDisable()		(ITC_AITEN &= ~(ITC_AITEN_AIEN2))
#define	ItcAdcEndIntDisable()		(ITC_AITEN &= ~(ITC_AITEN_AIEN3))
#define	ItcRtcIntDisable()			(ITC_AITEN &= ~(ITC_AITEN_AIEN4))
#define	ItcT8Ch0IntDisable()		(ITC_AITEN &= ~(ITC_AITEN_AIEN5))
#define	ItcT8Ch1IntDisable()		(ITC_AITEN &= ~(ITC_AITEN_AIEN6))
#define	ItcT8Ch2IntDisable()		(ITC_AITEN &= ~(ITC_AITEN_AIEN7))
#define	ItcT8Ch3IntDisable()		(ITC_AITEN &= ~(ITC_AITEN_AIEN8))
#define	ItcLcdcIntDisable()			(ITC_AITEN &= ~(ITC_AITEN_AIEN9))
#define	ItcEspiIntDisable()			(ITC_AITEN &= ~(ITC_AITEN_AIEN10))
#define	ItcUsbIntDisable()			(ITC_AITEN &= ~(ITC_AITEN_AIEN11))
#define	ItcI2sTranIntDisable()		(ITC_AITEN &= ~(ITC_AITEN_AIEN12))
#define	ItcI2sRcvIntDisable()		(ITC_AITEN &= ~(ITC_AITEN_AIEN13))
#define	ItcRemcIntDisable()			(ITC_AITEN &= ~(ITC_AITEN_AIEN14))

// For additional interrupt level setup register 0
#define	ItcSetAddIntLv0(x)			(ITC_ATILV0 = x)
#define	ItcGetAddIntLv0()			(ITC_ATILV0)
#define	ItcSetMftIntLv(x)			(ITC_ATILV0 = ((ITC_ATILV0 & ~(ITC_ATILV0_AILV0)) | (x & ITC_ATILV0_AILV0)))
#define	ItcGetMftIntLv()			(ITC_ATILV0 & ITC_ATILV0_AILV0)

// For additional interrupt level setup register 1
#define	ItcSetAddIntLv1(x)			(ITC_ATILV1 = x)
#define	ItcGetAddIntLv1()			(ITC_ATILV1)
#define	ItcSetAdcRangeIntLv(x)		(ITC_ATILV1 = ((ITC_ATILV1 & ~(ITC_ATILV1_AILV2)) | (x & ITC_ATILV1_AILV2)))
#define	ItcSetAdcEndIntLv(x)		(ITC_ATILV1 = ((ITC_ATILV1 & ~(ITC_ATILV1_AILV3)) | ((x << 8) & ITC_ATILV1_AILV3)))
#define	ItcGetAdcRangeIntLv()		(ITC_ATILV1 & ITC_ATILV1_AILV2)
#define	ItcGetAdcEndIntLv()			((ITC_ATILV1 & ITC_ATILV1_AILV3) >> 8)

// For additional interrupt level setup register 2
#define	ItcSetAddIntLv2(x)			(ITC_ATILV2 = x)
#define	ItcGetAddIntLv2()			(ITC_ATILV2)
#define	ItcSetRtcIntLv(x)			(ITC_ATILV2 = ((ITC_ATILV2 & ~(ITC_ATILV2_AILV4)) | (x & ITC_ATILV2_AILV4)))
#define	ItcSetT8Ch0IntLv(x)			(ITC_ATILV2 = ((ITC_ATILV2 & ~(ITC_ATILV2_AILV5)) | ((x << 8) & ITC_ATILV2_AILV5)))
#define	ItcGetRtcIntLv()			(ITC_ATILV2 & ITC_ATILV2_AILV4)
#define	ItcGetT8Ch0IntLv()			((ITC_ATILV2 & ITC_ATILV2_AILV5) >> 8)

// For additional interrupt level setup register 3
#define	ItcSetAddIntLv3(x)			(ITC_ATILV3 = x)
#define	ItcGetAddIntLv3()			(ITC_ATILV3)
#define	ItcSetT8Ch1IntLv(x)			(ITC_ATILV3 = ((ITC_ATILV3 & ~(ITC_ATILV3_AILV6)) | (x & ITC_ATILV3_AILV6)))
#define	ItcSetT8Ch2IntLv(x)			(ITC_ATILV3 = ((ITC_ATILV3 & ~(ITC_ATILV3_AILV7)) | ((x << 8) & ITC_ATILV3_AILV7)))
#define	ItcGetT8Ch1IntLv()			(ITC_ATILV3 & ITC_ATILV3_AILV6)
#define	ItcGetT8Ch2IntLv()			((ITC_ATILV3 & ITC_ATILV3_AILV7) >> 8)

// For additional interrupt level setup register 4
#define	ItcSetAddIntLv4(x)			(ITC_ATILV4 = x)
#define	ItcGetAddIntLv4()			(ITC_ATILV4)
#define	ItcSetT8Ch3IntLv(x)			(ITC_ATILV4 = ((ITC_ATILV4 & ~(ITC_ATILV4_AILV8)) | (x & ITC_ATILV4_AILV8)))
#define	ItcSetLcdcIntLv(x)			(ITC_ATILV4 = ((ITC_ATILV4 & ~(ITC_ATILV4_AILV9)) | ((x << 8) & ITC_ATILV4_AILV9)))
#define	ItcGetT8Ch3IntLv()			(ITC_ATILV4 & ITC_ATILV4_AILV8)
#define	ItcGetLcdcIntLv()			((ITC_ATILV4 & ITC_ATILV4_AILV9) >> 8)

// For additional interrupt level setup register 5
#define	ItcSetAddIntLv5(x)			(ITC_ATILV5 = x)
#define	ItcGetAddIntLv5()			(ITC_ATILV5)
#define	ItcSetEspiIntLv(x)			(ITC_ATILV5 = ((ITC_ATILV5 & ~(ITC_ATILV5_AILV10)) | (x & ITC_ATILV5_AILV10)))
#define	ItcSetUsbIntLv(x)			(ITC_ATILV5 = ((ITC_ATILV5 & ~(ITC_ATILV5_AILV11)) | ((x << 8) & ITC_ATILV5_AILV11)))
#define	ItcGetEspiIntLv()			(ITC_ATILV5 & ITC_ATILV5_AILV10)
#define	ItcGetUsbIntLv()			((ITC_ATILV5 & ITC_ATILV5_AILV11) >> 8)

// For additional interrupt level setup register 6
#define	ItcSetAddIntLv6(x)			(ITC_ATILV6 = x)
#define	ItcGetAddIntLv6()			(ITC_ATILV6)
#define	ItcSetI2sTranIntLv(x)		(ITC_ATILV6 = ((ITC_ATILV6 & ~(ITC_ATILV6_AILV12)) | (x & ITC_ATILV6_AILV12)))
#define	ItcSetI2sRcvIntLv(x)		(ITC_ATILV6 = ((ITC_ATILV6 & ~(ITC_ATILV6_AILV13)) | ((x << 8) & ITC_ATILV6_AILV13)))
#define	ItcGetI2sTranIntLv()		(ITC_ATILV6 & ITC_ATILV6_AILV12)
#define	ItcGetI2sRcvIntLv()			((ITC_ATILV6 & ITC_ATILV6_AILV13) >> 8)

// For additional interrupt level setup register 7
#define	ItcSetAddIntLv7(x)			(ITC_ATILV7 = x)
#define	ItcGetAddIntLv7()			(ITC_ATILV7)
#define	ItcSetRemcIntLv(x)			(ITC_ATILV7 = ((ITC_ATILV7 & ~(ITC_ATILV7_AILV14)) | (x & ITC_ATILV7_AILV14)))
#define	ItcGetRemcIntLv()			(ITC_ATILV7 & ITC_ATILV7_AILV14)

// For interrupt flag register
#define	ItcClrIntFlag(x)			(ITC_ITFT = x)
#define	ItcGetIntFlag()				(ITC_ITFT)
#define	ItcClrPort0Int()			(ITC_ITFT = ITC_ITFT_EIFT0)
#define	ItcClrPort1Int()			(ITC_ITFT = ITC_ITFT_EIFT1)
#define	ItcClrPort2Int()			(ITC_ITFT = ITC_ITFT_EIFT2)
#define	ItcClrPort3Int()			(ITC_ITFT = ITC_ITFT_EIFT3)
#define	ItcClrPort4Int()			(ITC_ITFT = ITC_ITFT_EIFT4)
#define	ItcClrPort5Int()			(ITC_ITFT = ITC_ITFT_EIFT5)
#define	ItcClrPort6Int()			(ITC_ITFT = ITC_ITFT_EIFT6)
#define	ItcClrPort7Int()			(ITC_ITFT = ITC_ITFT_EIFT7)
#define	ItcClrClgT16UInt()			(ITC_ITFT = ITC_ITFT_IIFT0)
#define	ItcClrClgT8SInt()			(ITC_ITFT = ITC_ITFT_IIFT2)
#define	ItcClrClgT8IInt()			(ITC_ITFT = ITC_ITFT_IIFT3)
#define	ItcClrUartInt()				(ITC_ITFT = ITC_ITFT_IIFT4)
#define	ItcClrSpiInt()				(ITC_ITFT = ITC_ITFT_IIFT6)
#define	ItcClrI2cInt()				(ITC_ITFT = ITC_ITFT_IIFT7)
#define	ItcGetPort0Int()			(ITC_ITFT & ITC_ITFT_EIFT0)
#define	ItcGetPort1Int()			((ITC_ITFT & ITC_ITFT_EIFT1) >> 1)
#define	ItcGetPort2Int()			((ITC_ITFT & ITC_ITFT_EIFT2) >> 2)
#define	ItcGetPort3Int()			((ITC_ITFT & ITC_ITFT_EIFT3) >> 3)
#define	ItcGetPort4Int()			((ITC_ITFT & ITC_ITFT_EIFT4) >> 4)
#define	ItcGetPort5Int()			((ITC_ITFT & ITC_ITFT_EIFT5) >> 5)
#define	ItcGetPort6Int()			((ITC_ITFT & ITC_ITFT_EIFT6) >> 6)
#define	ItcGetPort7Int()			((ITC_ITFT & ITC_ITFT_EIFT7) >> 7)
#define	ItcGetClgT16UInt()			((ITC_ITFT & ITC_ITFT_IIFT0) >> 8)
#define	ItcGetClgT8SInt()			((ITC_ITFT & ITC_ITFT_IIFT2) >> 10)
#define	ItcGetClgT8IInt()			((ITC_ITFT & ITC_ITFT_IIFT3) >> 11)
#define	ItcGetUartInt()				((ITC_ITFT & ITC_ITFT_IIFT4) >> 12)
#define	ItcGetSpiInt()				((ITC_ITFT & ITC_ITFT_IIFT6) >> 14)
#define	ItcGetI2cInt()				((ITC_ITFT & ITC_ITFT_IIFT7) >> 15)

// For interrupt enable register
#define	ItcSetIntEnable(x)			(ITC_ITEN = x)
#define	ItcGetIntEnable()			(ITC_ITEN)
#define	ItcPort0IntEnable()			(ITC_ITEN |= ITC_ITEN_EIEN0)
#define	ItcPort1IntEnable()			(ITC_ITEN |= ITC_ITEN_EIEN1)
#define	ItcPort2IntEnable()			(ITC_ITEN |= ITC_ITEN_EIEN2)
#define	ItcPort3IntEnable()			(ITC_ITEN |= ITC_ITEN_EIEN3)
#define	ItcPort4IntEnable()			(ITC_ITEN |= ITC_ITEN_EIEN4)
#define	ItcPort5IntEnable()			(ITC_ITEN |= ITC_ITEN_EIEN5)
#define	ItcPort6IntEnable()			(ITC_ITEN |= ITC_ITEN_EIEN6)
#define	ItcPort7IntEnable()			(ITC_ITEN |= ITC_ITEN_EIEN7)
#define	ItcClgT16UIntEnable()		(ITC_ITEN |= ITC_ITEN_IIEN0)
#define	ItcClgT8SIntEnable()		(ITC_ITEN |= ITC_ITEN_IIEN2)
#define	ItcClgT8IIntEnable()		(ITC_ITEN |= ITC_ITEN_IIEN3)
#define	ItcUartIntEnable()			(ITC_ITEN |= ITC_ITEN_IIEN4)
#define	ItcSpiIntEnable()			(ITC_ITEN |= ITC_ITEN_IIEN6)
#define	ItcI2cIntEnable()			(ITC_ITEN |= ITC_ITEN_IIEN7)
#define	ItcPort0IntDisable()		(ITC_ITEN &= ~(ITC_ITEN_EIEN0))
#define	ItcPort1IntDisable()		(ITC_ITEN &= ~(ITC_ITEN_EIEN1))
#define	ItcPort2IntDisable()		(ITC_ITEN &= ~(ITC_ITEN_EIEN2))
#define	ItcPort3IntDisable()		(ITC_ITEN &= ~(ITC_ITEN_EIEN3))
#define	ItcPort4IntDisable()		(ITC_ITEN &= ~(ITC_ITEN_EIEN4))
#define	ItcPort5IntDisable()		(ITC_ITEN &= ~(ITC_ITEN_EIEN5))
#define	ItcPort6IntDisable()		(ITC_ITEN &= ~(ITC_ITEN_EIEN6))
#define	ItcPort7IntDisable()		(ITC_ITEN &= ~(ITC_ITEN_EIEN7))
#define	ItcClgT16UIntDisable()		(ITC_ITEN &= ~(ITC_ITEN_IIEN0))
#define	ItcClgT8SIntDisable()		(ITC_ITEN &= ~(ITC_ITEN_IIEN2))
#define	ItcClgT8IIntDisable()		(ITC_ITEN &= ~(ITC_ITEN_IIEN3))
#define	ItcUartIntDisable()			(ITC_ITEN &= ~(ITC_ITEN_IIEN4))
#define	ItcSpiIntDisable()			(ITC_ITEN &= ~(ITC_ITEN_IIEN6))
#define	ItcI2cIntDisable()			(ITC_ITEN &= ~(ITC_ITEN_IIEN7))

// For ITC control register
#define	ItcFuncEnable()				(ITC_ITCTL |= ITC_ITCTL_ITEN)
#define	ItcFuncDisable()			(ITC_ITCTL &= ~(ITC_ITCTL_ITEN))

// For external interrupt level setup register 0
#define	ItcSetExtIntLv0(x)			(ITC_ITELV0 = x)
#define	ItcGetExtIntLv0()			(ITC_ITELV0)
#define	ItcSetPort0IntLv(x)			(ITC_ITELV0 = ((ITC_ITELV0 & ~(ITC_ITELV0_EILV0)) | (x & ITC_ITELV0_EILV0)))
#define	ItcSetPort1IntLv(x)			(ITC_ITELV0 = ((ITC_ITELV0 & ~(ITC_ITELV0_EILV1)) | ((x << 8) & ITC_ITELV0_EILV1)))
#define	ItcGetPort0IntLv(x)			(ITC_ITELV0 & ITC_ITELV0_EILV0)
#define	ItcGetPort1IntLv(x)			((ITC_ITELV0 & ITC_ITELV0_EILV1) >> 8)
#define	ItcSetPort0TmLevel()		(ITC_ITELV0 |= ITC_ITELV0_EITG0)
#define	ItcSetPort1TmLevel()		(ITC_ITELV0 |= ITC_ITELV0_EITG1)
#define	ItcSetPort0TmPulse()		(ITC_ITELV0 &= ~(ITC_ITELV0_EITG0))
#define	ItcSetPort1TmPulse()		(ITC_ITELV0 &= ~(ITC_ITELV0_EITG1))
#define	ItcSetPort0TpPos()			(ITC_ITELV0 |= ITC_ITELV0_EITP0)
#define	ItcSetPort1TpPos()			(ITC_ITELV0 |= ITC_ITELV0_EITP1)
#define	ItcSetPort0TpNeg()			(ITC_ITELV0 &= ~(ITC_ITELV0_EITP0))
#define	ItcSetPort1TpNeg()			(ITC_ITELV0 &= ~(ITC_ITELV0_EITP1))

// For external interrupt level setup register 1
#define	ItcSetExtIntLv1(x)			(ITC_ITELV1 = x)
#define	ItcGetExtIntLv1()			(ITC_ITELV1)
#define	ItcSetPort2IntLv(x)			(ITC_ITELV1 = ((ITC_ITELV1 & ~(ITC_ITELV1_EILV2)) | (x & ITC_ITELV1_EILV2)))
#define	ItcSetPort3IntLv(x)			(ITC_ITELV1 = ((ITC_ITELV1 & ~(ITC_ITELV1_EILV3)) | ((x << 8) & ITC_ITELV1_EILV3)))
#define	ItcGetPort2IntLv(x)			(ITC_ITELV1 & ITC_ITELV1_EILV2)
#define	ItcGetPort3IntLv(x)			((ITC_ITELV1 & ITC_ITELV1_EILV3) >> 8)
#define	ItcSetPort2TmLevel()		(ITC_ITELV1 |= ITC_ITELV1_EITG2)
#define	ItcSetPort3TmLevel()		(ITC_ITELV1 |= ITC_ITELV1_EITG3)
#define	ItcSetPort2TmPulse()		(ITC_ITELV1 &= ~(ITC_ITELV1_EITG2))
#define	ItcSetPort3TmPulse()		(ITC_ITELV1 &= ~(ITC_ITELV1_EITG3))
#define	ItcSetPort2TpPos()			(ITC_ITELV1 |= ITC_ITELV1_EITP2)
#define	ItcSetPort3TpPos()			(ITC_ITELV1 |= ITC_ITELV1_EITP3)
#define	ItcSetPort2TpNeg()			(ITC_ITELV1 &= ~(ITC_ITELV1_EITP2))
#define	ItcSetPort3TpNeg()			(ITC_ITELV1 &= ~(ITC_ITELV1_EITP3))

// For external interrupt level setup register 2
#define	ItcSetExtIntLv2(x)			(ITC_ITELV2 = x)
#define	ItcGetExtIntLv2()			(ITC_ITELV2)
#define	ItcSetPort4IntLv(x)			(ITC_ITELV2 = ((ITC_ITELV2 & ~(ITC_ITELV2_EILV4)) | (x & ITC_ITELV2_EILV4)))
#define	ItcSetPort5IntLv(x)			(ITC_ITELV2 = ((ITC_ITELV2 & ~(ITC_ITELV2_EILV5)) | ((x << 8) & ITC_ITELV2_EILV5)))
#define	ItcGetPort4IntLv(x)			(ITC_ITELV2 & ITC_ITELV2_EILV4)
#define	ItcGetPort5IntLv(x)			((ITC_ITELV2 & ITC_ITELV2_EILV5) >> 8)
#define	ItcSetPort4TmLevel()		(ITC_ITELV2 |= ITC_ITELV2_EITG4)
#define	ItcSetPort5TmLevel()		(ITC_ITELV2 |= ITC_ITELV2_EITG5)
#define	ItcSetPort4TmPulse()		(ITC_ITELV2 &= ~(ITC_ITELV2_EITG4))
#define	ItcSetPort5TmPulse()		(ITC_ITELV2 &= ~(ITC_ITELV2_EITG5))
#define	ItcSetPort4TpPos()			(ITC_ITELV2 |= ITC_ITELV2_EITP4)
#define	ItcSetPort5TpPos()			(ITC_ITELV2 |= ITC_ITELV2_EITP5)
#define	ItcSetPort4TpNeg()			(ITC_ITELV2 &= ~(ITC_ITELV2_EITP4))
#define	ItcSetPort5TpNeg()			(ITC_ITELV2 &= ~(ITC_ITELV2_EITP5))

// For external interrupt level setup register 3
#define	ItcSetExtIntLv3(x)			(ITC_ITELV3 = x)
#define	ItcGetExtIntLv3()			(ITC_ITELV3)
#define	ItcSetPort6IntLv(x)			(ITC_ITELV3 = ((ITC_ITELV3 & ~(ITC_ITELV3_EILV6)) | (x & ITC_ITELV3_EILV6)))
#define	ItcSetPort7IntLv(x)			(ITC_ITELV3 = ((ITC_ITELV3 & ~(ITC_ITELV3_EILV7)) | ((x << 8) & ITC_ITELV3_EILV7)))
#define	ItcGetPort6IntLv(x)			(ITC_ITELV3 & ITC_ITELV3_EILV6)
#define	ItcGetPort7IntLv(x)			((ITC_ITELV3 & ITC_ITELV3_EILV7) >> 8)
#define	ItcSetPort6TmLevel()		(ITC_ITELV3 |= ITC_ITELV3_EITG6)
#define	ItcSetPort7TmLevel()		(ITC_ITELV3 |= ITC_ITELV3_EITG7)
#define	ItcSetPort6TmPulse()		(ITC_ITELV3 &= ~(ITC_ITELV3_EITG6))
#define	ItcSetPort7TmPulse()		(ITC_ITELV3 &= ~(ITC_ITELV3_EITG7))
#define	ItcSetPort6TpPos()			(ITC_ITELV3 |= ITC_ITELV3_EITP6)
#define	ItcSetPort7TpPos()			(ITC_ITELV3 |= ITC_ITELV3_EITP7)
#define	ItcSetPort6TpNeg()			(ITC_ITELV3 &= ~(ITC_ITELV3_EITP6))
#define	ItcSetPort7TpNeg()			(ITC_ITELV3 &= ~(ITC_ITELV3_EITP7))

// For internal interrupt level setup register 0
#define	ItcSetInIntLv0(x)			(ITC_ITILV0 = x)
#define	ItcGetInIntLv0()			(ITC_ITILV0)
#define	ItcSetClgT16UIntLv(x)		(ITC_ITILV0 = ((ITC_ITILV0 & ~(ITC_ITILV0_IILV0)) | (x & ITC_ITILV0_IILV0)))
#define	ItcGetClgT16UIntLv()		(ITC_ITILV0 & ITC_ITILV0_IILV0)

// For internal interrupt level setup register 1
#define	ItcSetInIntLv1(x)			(ITC_ITILV1 = x)
#define	ItcGetInIntLv1()			(ITC_ITILV1)
#define	ItcSetClgT8SIntLv(x)		(ITC_ITILV1 = ((ITC_ITILV1 & ~(ITC_ITILV1_IILV2)) | (x & ITC_ITILV1_IILV2)))
#define	ItcSetClgT8IIntLv(x)		(ITC_ITILV1 = ((ITC_ITILV1 & ~(ITC_ITILV1_IILV3)) | ((x << 8) & ITC_ITILV1_IILV3)))
#define	ItcGetClgT8SIntLv()			(ITC_ITILV1 & ITC_ITILV1_IILV2)
#define	ItcGetClgT8IIntLv()			((ITC_ITILV1 & ITC_ITILV1_IILV3) >> 8)

// For internal interrupt level setup register 2
#define	ItcSetInIntLv2(x)			(ITC_ITILV2 = x)
#define	ItcGetInIntLv2()			(ITC_ITILV2)
#define	ItcSetUartIntLv(x)			(ITC_ITILV2 = ((ITC_ITILV2 & ~(ITC_ITILV2_IILV4)) | (x & ITC_ITILV2_IILV4)))
#define	ItcGetUartIntLv()			(ITC_ITILV2 & ITC_ITILV2_IILV4)

// For internal interrupt level setup register 3
#define	ItcSetInIntLv3(x)			(ITC_ITILV3 = x)
#define	ItcGetInIntLv3()			(ITC_ITILV3)
#define	ItcSetSpiLv(x)				(ITC_ITILV3 = ((ITC_ITILV3 & ~(ITC_ITILV3_IILV6)) | (x & ITC_ITILV3_IILV6)))
#define	ItcSetI2cIntLv(x)			(ITC_ITILV3 = ((ITC_ITILV3 & ~(ITC_ITILV3_IILV7)) | ((x << 8) & ITC_ITILV3_IILV7)))
#define	ItcGetSpiIntLv()			(ITC_ITILV3 & ITC_ITILV3_IILV6)
#define	ItcGetI2cIntLv()			((ITC_ITILV3 & ITC_ITILV3_IILV7) >> 8)


#ifdef	__cplusplus
extern "C" {
#endif

// ITC APIs
extern void ItcInit(T_ITC_CFG *pConfig);


#ifdef __cplusplus
}
#endif

#endif	// __ITC_API_H__

