/***************************************************************************
*
*	File name : main.c
*	Function  : Main function
*	Revision  :
*		07/31/2007	Nariai		First revision
*
****************************************************************************/

// Include File
#include	<string.h>
#include	<stdio.h>
#include	<stdlib.h>
#include	<libstdio.h>
#include	"reg_801.h"
#include	"clg_api.h"
#include	"clg_drv.h"
#include	"itc_api.h"


// Define
#define	CpuIntEnable()		asm("ei")
#define	CpuIntDisable()		asm("di")
#define	PrescalerOn()		PSC_CTL		= PSC_CTL_PRUN


// Prototype
int main(void);
static void ExeClgforUART(void);
static void ExeClgforSPI(void);
static void ExeClgforI2C(void);


/***************************************************************************
	main

	description	: main function
	argument	: None
	return: 	: None
***************************************************************************/
int main(void){
	
	T_CLG_CFG			clgConfig;
	
	// CPU interrupt enable
	CpuIntEnable();
	
	// Prescaler On
	PrescalerOn();
	
	// Setting ITC for MFT
	ItcClgT16UIntDisable();			// CLG for UART
	ItcClrClgT16UInt();
	ItcSetClgT16UIntLv(5);
	ItcClgT8SIntDisable();			// CLG for SPI
	ItcClrClgT8SInt();
	ItcSetClgT8SIntLv(5);
	ItcClgT8IIntDisable();			// CLG for I2C
	ItcClrClgT8IInt();
	ItcSetClgT8IIntLv(5);
	ItcFuncEnable();
	
	// Init.CLG UART 0
	clgConfig.countMode			= CLG_COUNT_REPEAT;
	clgConfig.inputClockSel		= CLG_INPUT_PCLK_4096;
	clgConfig.reloadData		= 12000;				// 1s
	ClgInit(CLG_FOR_UART0, &clgConfig);
	
	// Init.CLG SPI
	clgConfig.countMode			= CLG_COUNT_REPEAT;
	clgConfig.inputClockSel		= CLG_INPUT_PCLK_4096;
	clgConfig.reloadData		= 0x0C;					// 1ms
	ClgInit(CLG_FOR_SPI, &clgConfig);
	
	// Init.CLG I2C
	clgConfig.countMode			= CLG_COUNT_REPEAT;
	clgConfig.inputClockSel		= CLG_INPUT_PCLK_4096;
	clgConfig.reloadData		= 0x0C;					// 1ms
	ClgInit(CLG_FOR_I2C, &clgConfig);
	
	// Execute each CLG
	ExeClgforUART();
	ExeClgforSPI();
	ExeClgforI2C();
	
	return 0;

}

/***************************************************************************
	PortInitialize

	description	: Init. Port
	argument	: None
	return: 	: None

	input		:
	output		:

	flag		: None
	global		: None
***************************************************************************/
static void PortInitialize(void){

	return;
}

/***************************************************************************
	ItcInitialize

	description	: Init. ITC
	argument	: None
	return: 	: None

	input		:
	output		:

	flag		: None
	global		: None
***************************************************************************/
static void ItcInitialize(void){

	T_ITC_CFG	itcConfig;

	itcConfig.addIntEn.bit.mft			= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.adcRange		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.adcEnd		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.rtc			= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.t8Ch0		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.t8Ch1		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.t8Ch2		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.t8Ch3		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.lcdc			= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.espi			= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.usb			= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.i2sTran		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.i2sRcv		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.remc			= ITC_INT_DISABLE;

	itcConfig.addIntLv0.bit.mft			= 0;
	itcConfig.addIntLv1.bit.adcRange	= 0;
	itcConfig.addIntLv1.bit.adcEnd		= 0;
	itcConfig.addIntLv2.bit.rtc			= 0;
	itcConfig.addIntLv2.bit.t8Ch0		= 7;
	itcConfig.addIntLv3.bit.t8Ch1		= 7;
	itcConfig.addIntLv3.bit.t8Ch2		= 7;
	itcConfig.addIntLv4.bit.t8Ch3		= 7;
	itcConfig.addIntLv4.bit.lcdc		= 0;
	itcConfig.addIntLv5.bit.espi		= 0;
	itcConfig.addIntLv5.bit.usb			= 0;
	itcConfig.addIntLv6.bit.i2sTran		= 7;
	itcConfig.addIntLv6.bit.i2sRcv		= 7;
	itcConfig.addIntLv7.bit.remc		= 0;

	itcConfig.intEn.bit.port0			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.port1			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.port2			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.port3			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.port4			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.port5			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.port6			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.port7			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.clgT16U			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.clgT8S			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.clgT8I			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.uart			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.spi				= ITC_INT_DISABLE;
	itcConfig.intEn.bit.i2c				= ITC_INT_DISABLE;

	itcConfig.extIntLv0.bit.port0		= 3;
	itcConfig.extIntLv0.bit.port0_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv0.bit.port0_TP	= ITC_TP_POSITIVE;
	itcConfig.extIntLv0.bit.port1		= 3;
	itcConfig.extIntLv0.bit.port1_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv0.bit.port1_TP	= ITC_TP_POSITIVE;
	itcConfig.extIntLv1.bit.port2		= 3;
	itcConfig.extIntLv1.bit.port2_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv1.bit.port2_TP	= ITC_TP_POSITIVE;
	itcConfig.extIntLv1.bit.port3		= 3;
	itcConfig.extIntLv1.bit.port3_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv1.bit.port3_TP	= ITC_TP_POSITIVE;
	itcConfig.extIntLv2.bit.port4		= 3;
	itcConfig.extIntLv2.bit.port4_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv2.bit.port4_TP	= ITC_TP_POSITIVE;
	itcConfig.extIntLv2.bit.port5		= 3;
	itcConfig.extIntLv2.bit.port5_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv2.bit.port5_TP	= ITC_TP_POSITIVE;
	itcConfig.extIntLv3.bit.port6		= 3;
	itcConfig.extIntLv3.bit.port6_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv3.bit.port6_TP	= ITC_TP_POSITIVE;
	itcConfig.extIntLv3.bit.port7		= 3;
	itcConfig.extIntLv3.bit.port7_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv3.bit.port7_TP	= ITC_TP_POSITIVE;

	itcConfig.inIntLv0.bit.clgT16U		= 3;
	itcConfig.inIntLv1.bit.clgT8S		= 3;
	itcConfig.inIntLv1.bit.clgT8I		= 3;
	itcConfig.inIntLv2.bit.uart			= 3;
	itcConfig.inIntLv3.bit.spi			= 3;
	itcConfig.inIntLv3.bit.i2c			= 7;

	itcConfig.funcEnable				= ITC_FUNC_ENABLE;

	ItcInit(&itcConfig);

	return;

}

/***************************************************************************
	ExeClgforUART

	description	: Execute CLG for UART
	argument	: None
	return: 	: None
***************************************************************************/
void ExeClgforUART(void){
	
	extern unsigned short	g_ClgUartCnt;
	unsigned short			counter = 0;
	
	// Start CLG
	ClgStart(CLG_FOR_UART0);
	
	// Enable CLG(UART) interrupt
	ItcClgT16UIntEnable();
	
	printf("> CLG(UART) Start\n");
	
	while(1){
		
		if(g_ClgUartCnt != 0){
			g_ClgUartCnt	= 0;
			
			counter++;
			printf("> CLG(UART) Interrupt ! : %d times\n", counter);
			
			if(counter < 10){
				// NULL
				
			} else {
				break;
				
			}
			
		}
		
	}
	
	ClgStop(CLG_FOR_UART0);
	
	printf("> CLG(UART) End\n\n");
	
	return;
	
}


/***************************************************************************
	ExeClgforSPI

	description	: Execute CLG for SPI
	argument	: None
	return: 	: None
***************************************************************************/
void ExeClgforSPI(void){
	
	extern unsigned short	g_ClgSpiCnt;
	unsigned short			counter = 0;
	
	// Start CLG
	ClgStart(CLG_FOR_SPI);
	
	// Enable CLG(UART) interrupt
	ItcClgT8SIntEnable();
	
	printf("> CLG(SPI) Start\n");
	
	while(1){
		
		if(g_ClgSpiCnt == 1000){
			g_ClgSpiCnt	= 0;
			
			counter++;
			printf("> CLG(SPI) Interrupt ! : %d times\n", counter);
			
			if(counter < 10){
				// NULL
				
			} else {
				break;
				
			}
			
		}
		
	}
	
	ClgStop(CLG_FOR_SPI);
	
	printf("> CLG(SPI) End\n\n");
	
	return;
	
}


/***************************************************************************
	ExeClgforI2C

	description	: Execute CLG for I2C
	argument	: None
	return: 	: None
***************************************************************************/
void ExeClgforI2C(void){
	
	extern unsigned short	g_ClgI2cCnt;
	unsigned short			counter = 0;
	
	// Start CLG
	ClgStart(CLG_FOR_I2C);
	
	// Enable CLG(UART) interrupt
	ItcClgT8IIntEnable();
	
	printf("> CLG(I2C) Start\n");
	
	while(1){
		
		if(g_ClgI2cCnt == 1000){
			g_ClgI2cCnt	= 0;
			
			counter++;
			printf("> CLG(I2C) Interrupt ! : %d times\n", counter);
			
			if(counter < 10){
				// NULL
				
			} else {
				break;
				
			}
			
		}
		
	}
	
	ClgStop(CLG_FOR_I2C);
	
	printf("> CLG(I2C) End\n");
	
	return;
	
}


